"""Mappings for gender specific mixed keys."""

from ...helps import len_print
from ..companies import companies_data

structures_data = {
    "energy companies": "شركات طاقة",
    "energy infrastructure": "بنية تحتية طاقة",
    "renewable resource companies": "شركات موارد متجددة",
    "electric power infrastructure": "بنية تحتية طاقة كهربائية",
    "hydroelectric power stations": "محطات طاقة كهرمائية",
    "mining disasters": "كوارث التعدين",
    "non-renewable resource companies": "شركات موارد غير متجددة",
    "energy companies of": "شركات طاقة في",
    "chemical companies": "شركات كيميائية",
    "renewable energy power stations": "محطات طاقة متجددة",
    "energy power stations": "محطات طاقة",
    "gas companies": "شركات غاز",
    "gas companies of": "شركات غاز في",
    "mining companies": "شركات التعدين",
    "oil and gas companies": "شركات النفط والغاز",
    "gas pipelines": "خطوط أنابيب غاز",
    "natural gas pipelines": "خطوط أنابيب غاز طبيعي",
    "electric power companies": "شركات طاقة كهربائية",
    "oil and gas companies of": "شركات النفط والغاز في",
    "electric power companies of": "شركات طاقة كهربائية في",
    "mining companies of": "شركات التعدين في",
    "oil fields": "حقول نفطية",
    "solar power stations": "محطات طاقة شمسية",
    "nuclear power stations": "محطات طاقة نووية",
    "coal mining": "تعدين الفحم",
    "mobile phone companies": "شركات هاتف محمول",
    "fossil fuel power stations": "محطات طاقة وقود أحفوري",
    "mobile phone companies of": "شركات هاتف محمول في",
    "oil pipelines": "خطوط أنابيب نفطية",
    "gas fields": "حقول غاز",
    "nuclear technology": "تقانة نووية",
    "oil refineries": "مصافي نفطية",
    "natural gas fields": "حقول غاز طبيعي",
    "chemical companies of": "شركات كيميائية في",
    "proposed renewable energy power stations": "محطات طاقة متجددة مقترحة",
    "petroleum industry": "صناعة بترولية",
    "oil companies": "شركات نفطية",
    "coal companies": "شركات الفحم",
    "oil companies of": "شركات نفطية في",
    "gold mining": "تعدين الذهب",
    "coal companies of": "شركات الفحم في",
    "hydroelectric power plants": "محطات طاقة كهرمائية",
    "mining museums": "متاحف التعدين",
    "gas stations": "محطات غاز",
    "geothermal energy": "طاقة حرارية جوفية",
    "nuclear power plants": "محطات طاقة نووية",
    "copper mining": "تعدين النحاس",
    "geothermal power stations": "محطات طاقة حرارية جوفية",
    "coal fields": "حقول الفحم",
    "natural gas companies": "شركات غاز طبيعي",
    "nuclear energy": "طاقة نووية",
    "photovoltaic power stations": "محطات طاقة كهروضوئية",
    "solar energy": "طاقة شمسية",
    "natural gas companies of": "شركات غاز طبيعي في",
    "chemical industry": "صناعة كيميائية",
    "renewable energy companies": "شركات طاقة متجددة",
    "biofuel power stations": "محطات طاقة وقود حيوي",
    "renewable energy companies of": "شركات طاقة متجددة في",
    "energy industry": "صناعة طاقة",
    "oil industry": "صناعة نفطية",
    "oil and gas fields": "حقول النفط والغاز",
    "former nuclear power stations": "محطات طاقة نووية سابقة",
    "petroleum infrastructure": "بنية تحتية بترولية",
    "electrical engineering companies": "شركات هندسة كهربائية",
    "chemical technology": "تقانة كيميائية",
    "gas industry": "صناعة غاز",
    "condiment companies": "شركات توابل",
    "electrical engineering companies of": "شركات هندسة كهربائية في",
    "nuclear bunkers": "مخابئ نووية",
    "natural gas industry": "صناعة غاز طبيعي",
    "condiment companies of": "شركات توابل في",
    "natural gas infrastructure": "بنية تحتية غاز طبيعي",
    "gas infrastructure": "بنية تحتية غاز",
    "proposed solar power stations": "محطات طاقة شمسية مقترحة",
    "coal industry": "صناعة الفحم",
    "energy organizations": "منظمات طاقة",
    "nuclear organizations": "منظمات نووية",
    "bauxite mining": "تعدين البوكسيت",
    "energy technology": "تقانة طاقة",
    "mobile phone industry": "صناعة هاتف محمول",
    "chemical structures": "منشآت كيميائية",
    "petroleum geology": "جيولوجيا بترولية",
    "renewable energy organizations": "منظمات طاقة متجددة",
    "nuclear facilities": "مرافق نووية",
    "oil shale companies": "شركات صخر زيتي",
    "oil shale mining": "تعدين صخر زيتي",
    "proposed nuclear power stations": "محطات طاقة نووية مقترحة",
    "petroleum buildings": "مبان بترولية",
    "petroleum buildings and structures": "مبان ومنشآت بترولية",
    "energy issues": "قضايا طاقة",
    "nuclear issues": "قضايا نووية",
    "petroleum politics": "سياسة بترولية",
    "chemical energy": "طاقة كيميائية",
    "coal museums": "متاحف الفحم",
    "energy agencies": "وكالات طاقة",
    "energy museums": "متاحف طاقة",
    "former biofuel power stations": "محطات طاقة وقود حيوي سابقة",
    "electric infrastructure": "بنية تحتية قدرة",
    "mining industry": "صناعة التعدين",
    "nuclear industry": "صناعة نووية",
    "oil and gas industry": "صناعة النفط والغاز",
    "oil shale companies of": "شركات صخر زيتي في",
    "oil shale technology": "تقانة صخر زيتي",
    "renewable energy technology": "تقانة طاقة متجددة",
    "chemical disasters": "كوارث كيميائية",
    "coal infrastructure": "بنية تحتية الفحم",
    "coal organizations": "منظمات الفحم",
    "coal technology": "تقانة الفحم",
    "copper industry": "صناعة النحاس",
    "electrical engineering organizations": "منظمات هندسة كهربائية",
    "electric fields": "حقول قدرة",
    "electric power industry": "صناعة طاقة كهربائية",
    "electric power industry organizations": "منظمات صناعة طاقة كهربائية",
    "energy industry organizations": "منظمات صناعة طاقة",
    "former hydroelectric power stations": "محطات طاقة كهرمائية سابقة",
    "gas museums": "متاحف غاز",
    "gold fields": "حقول الذهب",
    "gold industry": "صناعة الذهب",
    "gold museums": "متاحف الذهب",
    "governmental nuclear organizations": "منظمات نووية حكومية",
    "natural gas power stations": "محطات طاقة غاز طبيعي",
    "gas power stations": "محطات طاقة غاز",
    "nuclear disasters": "كوارث نووية",
    "mining organizations": "منظمات التعدين",
    "natural gas organizations": "منظمات غاز طبيعي",
    "gas organizations": "منظمات غاز",
    "natural gas technology": "تقانة غاز طبيعي",
    "gas technology": "تقانة غاز",
    "non-renewable energy companies": "شركات طاقة غير متجددة",
    "nuclear companies": "شركات نووية",
    "nuclear companies of": "شركات نووية في",
    "nuclear industry organizations": "منظمات صناعة نووية",
    "nuclear organization": "منظمات نووية",
    "oil infrastructure": "بنية تحتية نفطية",
    "oil shale geology": "جيولوجيا صخر زيتي",
    "oil shale infrastructure": "بنية تحتية صخر زيتي",
    "electric industry": "صناعة قدرة",
    "electric stations": "محطات قدرة",
    "petroleum museums": "متاحف بترولية",
    "petroleum organizations": "منظمات بترولية",
    "petroleum technology": "تقانة بترولية",
    "energy organization": "منظمات طاقة",
    "proposed biofuel power stations": "محطات طاقة وقود حيوي مقترحة",
    "proposed fossil fuel power stations": "محطات طاقة وقود أحفوري مقترحة",
    "proposed geothermal power stations": "محطات طاقة حرارية جوفية مقترحة",
    "proposed hydroelectric power stations": "محطات طاقة كهرمائية مقترحة",
    "renewable energy power plants": "محطات طاقة متجددة",
    "energy power plants": "محطات طاقة",
    "energy facilities": "مرافق طاقة",
}


religious_entries = {
    "bahá'í buildings and structures": "مبان ومنشآت بهائية",
    "bahá'í buildings": "مبان بهائية",
    "bahá'í educational institutions": "هيئات تعليمية بهائية",
    "bahá'í educational": "تعليمية بهائية",
    "bahá'í institutions": "مؤسسات بهائية",
    "buddhist buildings and structures": "مبان ومنشآت بوذية",
    "buddhist buildings": "مبان بوذية",
    "buddhist charities": "جمعيات خيرية بوذية",
    "buddhist communities": "مجتمعات بوذية",
    "buddhist culture": "ثقافة بوذية",
    "buddhist educational institutions": "هيئات تعليمية بوذية",
    "buddhist educational": "تعليمية بوذية",
    "buddhist festivals": "مهرجانات بوذية",
    "buddhist movements": "حركات بوذية",
    "buddhist museums": "متاحف بوذية",
    "buddhist orders": "أخويات بوذية",
    "buddhist organisations": "منظمات بوذية",
    "buddhist organization": "منظمات بوذية",
    "buddhist organizations": "منظمات بوذية",
    "buddhist religious occupations": "مهن دينية بوذية",
    "buddhist schools": "مدارس بوذية",
    "buddhist temples": "معابد بوذية",
    "buddhist women's organizations": "منظمات نسائية بوذية",
    "buddhist youth organizations": "منظمات شبابية بوذية",
    "christian buildings and structures": "مبان ومنشآت مسيحية",
    "christian buildings": "مبان مسيحية",
    "christian charities": "جمعيات خيرية مسيحية",
    "christian communities": "مجتمعات مسيحية",
    "christian culture": "ثقافة مسيحية",
    "christian denominations": "طوائف مسيحية",
    "christian educational institutions": "هيئات تعليمية مسيحية",
    "christian educational": "تعليمية مسيحية",
    "christian festivals": "مهرجانات مسيحية",
    "christian groups": "مجموعات مسيحية",
    "christian movements": "حركات مسيحية",
    "christian museums": "متاحف مسيحية",
    "christian orders": "أخويات مسيحية",
    "christian organisations": "منظمات مسيحية",
    "christian organization": "منظمات مسيحية",
    "christian religious occupations": "مهن دينية مسيحية",
    "christian schools": "مدارس مسيحية",
    "christian societies": "جمعيات مسيحية",
    "christian student organizations": "منظمات طلابية مسيحية",
    "christian women's organizations": "منظمات نسائية مسيحية",
    "christian youth organizations": "منظمات شبابية مسيحية",
    "hindu buildings and structures": "مبان ومنشآت هندوسية",
    "hindu buildings": "مبان هندوسية",
    "hindu communities": "مجتمعات هندوسية",
    "hindu culture": "ثقافة هندوسية",
    "hindu denominations": "طوائف هندوسية",
    "hindu educational institutions": "هيئات تعليمية هندوسية",
    "hindu educational": "تعليمية هندوسية",
    "hindu festivals": "مهرجانات هندوسية",
    "hindu groups": "مجموعات هندوسية",
    "hindu movements": "حركات هندوسية",
    "hindu organisations": "منظمات هندوسية",
    "hindu organizations": "منظمات هندوسية",
    "hindu religious orders": "أخويات دينية هندوسية",
    "hindu schools": "مدارس هندوسية",
    "hindu temples": "معابد هندوسية",
    "islamic awards": "جوائز إسلامية",
    "islamic banks": "بنوك إسلامية",
    "islamic buildings and structures": "مبان ومنشآت إسلامية",
    "islamic buildings": "مبان إسلامية",
    "islamic charities": "جمعيات خيرية إسلامية",
    "islamic culture": "ثقافة إسلامية",
    "islamic educational institutions": "هيئات تعليمية إسلامية",
    "islamic educational": "تعليمية إسلامية",
    "islamic festivals": "مهرجانات إسلامية",
    "islamic movements": "حركات إسلامية",
    "islamic museums": "متاحف إسلامية",
    "islamic orders": "أخويات إسلامية",
    "islamic organisations": "منظمات إسلامية",
    "islamic organization": "منظمات إسلامية",
    "islamic organizations": "منظمات إسلامية",
    "islamic politics": "سياسة إسلامية",
    "islamic religious occupations": "مهن دينية إسلامية",
    "islamic schools": "مدارس إسلامية",
    "islamic youth organizations": "منظمات شبابية إسلامية",
    "jain communities": "مجتمعات جاينية",
    "jain culture": "ثقافة جاينية",
    "jain festivals": "مهرجانات جاينية",
    "jain organisations": "منظمات جاينية",
    "jain religious occupations": "مهن دينية جاينية",
    "jain temples": "معابد جاينية",
    "jewish buildings and structures": "مبان ومنشآت يهودية",
    "jewish buildings": "مبان يهودية",
    "jewish charities": "جمعيات خيرية يهودية",
    "jewish clubs": "نوادي يهودية",
    "jewish communities": "مجتمعات يهودية",
    "jewish culture": "ثقافة يهودية",
    "jewish educational institutions": "هيئات تعليمية يهودية",
    "jewish educational": "تعليمية يهودية",
    "jewish federations": "اتحادات يهودية",
    "jewish festivals": "مهرجانات يهودية",
    "jewish groups": "مجموعات يهودية",
    "jewish institutions": "مؤسسات يهودية",
    "jewish movements": "حركات يهودية",
    "jewish museums": "متاحف يهودية",
    "jewish organisations": "منظمات يهودية",
    "jewish organization": "منظمات يهودية",
    "jewish religious occupations": "مهن دينية يهودية",
    "jewish schools": "مدارس يهودية",
    "jewish services": "خدمات يهودية",
    "jewish women's organizations": "منظمات نسائية يهودية",
    "jewish youth organizations": "منظمات شبابية يهودية",
    "masonic buildings": "مبان ماسونية",
    "masonic culture": "ثقافة ماسونية",
    "masonic educational institutions": "هيئات تعليمية ماسونية",
    "masonic educational": "تعليمية ماسونية",
    "masonic museums": "متاحف ماسونية",
    "masonic organizations": "منظمات ماسونية",
    "masonic youth organizations": "منظمات شبابية ماسونية",
    "new religious movements": "حركات دينية جديدة",
    "new thought denominations": "طوائف فكر جديد",
    "new thought organizations": "منظمات فكر جديد",
    "political party founders": "مؤسسو أحزاب سياسية",
    "protestant buildings and structures": "مبان ومنشآت بروتستانتية",
    "protestant buildings": "مبان بروتستانتية",
    "protestant denominations": "طوائف بروتستانتية",
    "protestant educational institutions": "هيئات تعليمية بروتستانتية",
    "protestant educational": "تعليمية بروتستانتية",
    "protestant orders": "أخويات بروتستانتية",
    "protestant organizations": "منظمات بروتستانتية",
    "protestant schools": "مدارس بروتستانتية",
    "religious academies": "أكاديميات دينية",
    "religious awards": "جوائز دينية",
    "religious building and structure": "مبان ومنشآت دينية",
    "religious buildings and structures": "مبان ومنشآت دينية",
    "religious buildings": "مبان دينية",
    "religious charities": "جمعيات خيرية دينية",
    "religious communities": "مجتمعات دينية",
    "religious corporations": "مؤسسات تجارية دينية",
    "religious culture": "ثقافة دينية",
    "religious denominations": "طوائف دينية",
    "religious educational institutions": "هيئات تعليمية دينية",
    "religious educational": "تعليمية دينية",
    "religious festivals": "مهرجانات دينية",
    "religious groups": "مجموعات دينية",
    "religious movements": "حركات دينية",
    "religious museums": "متاحف دينية",
    "religious occupations": "مهن دينية",
    "religious orders": "أخويات دينية",
    "religious organisations": "منظمات دينية",
    "religious organization": "منظمات دينية",
    "religious organizations": "منظمات دينية",
    "religious schools": "مدارس دينية",
    "religious service organizations": "منظمات خدمية دينية",
    "religious temples": "معابد دينية",
    "scientology organization": "منظمات سينتولوجيا",
    "scientology organizations": "منظمات سينتولوجيا",
    "sikh communities": "مجتمعات سيخية",
    "sikh culture": "ثقافة سيخية",
    "sikh festivals": "مهرجانات سيخية",
    "sikh groups": "مجموعات سيخية",
    "sikh organisations": "منظمات سيخية",
    "sikh organizations": "منظمات سيخية",
    "sikh politics": "سياسة سيخية",
    "spiritualist communities": "مجتمعات روحانية",
    "spiritualist organizations": "منظمات روحانية",
    "taoist buildings and structures": "مبان ومنشآت طاوية",
    "taoist buildings": "مبان طاوية",
    "taoist communities": "مجتمعات طاوية",
    "taoist culture": "ثقافة طاوية",
    "taoist festivals": "مهرجانات طاوية",
    "taoist organizations": "منظمات طاوية",
    "taoist schools": "مدارس طاوية",
    "taoist temples": "معابد طاوية",
    "unitarian universalist organizations": "منظمات توحيدية عالمية",
    "zoroastrian culture": "ثقافة زرادشتية",
    "zoroastrian festivals": "مهرجانات زرادشتية",
    "zoroastrian organizations": "منظمات زرادشتية",
}

films_data = {
    "educational organizations": "منظمات تعليمية",
    "religious organizations": "منظمات دينية",
    "sports organizations": "منظمات رياضية",
    "student organizations": "منظمات طلاب",
    "political organizations": "منظمات سياسية",
    "political organisations": "منظمات سياسية",
    "lgbtq culture": "ثقافة إل جي بي تي كيو",
    "religious organisations": "منظمات دينية",
    "sports organisations": "منظمات رياضية",
    "educational organisations": "منظمات تعليمية",
    "sex industry": "صناعة جنسية",
    "music organisations": "منظمات موسيقية",
    "music organizations": "منظمات موسيقية",
    "internet culture": "ثقافة إنترنت",
    "music industry": "صناعة موسيقية",
    "television companies": "شركات تلفزيونية",
    "aviation organisations": "منظمات طيران",
    "feminist organisations": "منظمات نسوية",
    "feminist organizations": "منظمات نسوية",
    "lgbtq organisations": "منظمات إل جي بي تي كيو",
    "lgbtq organizations": "منظمات إل جي بي تي كيو",
    "aviation organizations": "منظمات طيران",
    "student organisations": "منظمات طلاب",
    "sports companies": "شركات رياضية",
    "military occupations": "مهن عسكرية",
    "dance companies": "شركات رقص",
    "television organizations": "منظمات تلفزيونية",
    "sports culture": "ثقافة رياضية",
    "music companies": "شركات موسيقية",
    "legal organizations": "منظمات قانونية",
    "military research": "أبحاث عسكرية",
    "legal organisations": "منظمات قانونية",
    "internet technology": "تقانة إنترنت",
    "educational technology": "تقانة تعليمية",
    "television organisations": "منظمات تلفزيونية",
    "military organizations": "منظمات عسكرية",
    "aviation organization": "منظمات طيران",
    "maritime organization": "منظمات بحرية",
    "religious occupations": "مهن دينية",
    "science organizations": "منظمات علمية",
    "legal issues": "قضايا قانونية",
    "maritime culture": "ثقافة بحرية",
    "student culture": "ثقافة طلاب",
    "science research": "أبحاث علمية",
    "propaganda organizations": "منظمات دعائية",
    "propaganda organisations": "منظمات دعائية",
    "maritime organisations": "منظمات بحرية",
    "military culture": "ثقافة عسكرية",
    "aviation companies": "شركات طيران",
    "criminal organization": "منظمات جنائية",
    "dance organizations": "منظمات رقص",
    "political culture": "ثقافة سياسية",
    "historical research": "أبحاث تاريخية",
    "television technology": "تقانة تلفزيونية",
    "military organization": "منظمات عسكرية",
    "school organizations": "منظمات مدرسية",
    "legal occupations": "مهن قانونية",
    "criminal organizations": "منظمات جنائية",
    "political organization": "منظمات سياسية",
    "educational research": "أبحاث تعليمية",
    "military technology": "تقانة عسكرية",
    "anime industry": "صناعة أنمي",
    "internet companies": "شركات إنترنت",
    "independent agencies": "وكالات مستقلة",
    "maritime disasters": "كوارث بحرية",
    "maritime organizations": "منظمات بحرية",
    "martial arts organizations": "منظمات فنون قتال",
    "science occupations": "مهن علمية",
    "religious organization": "منظمات دينية",
    "independent research": "أبحاث مستقلة",
    "aviation industry": "صناعة طيران",
    "aviation technology": "تقانة طيران",
    "black culture": "ثقافة سوداء",
    "maritime industry": "صناعة بحرية",
    "lgbtq issues": "قضايا إل جي بي تي كيو",
    "political research": "أبحاث سياسية",
    "sports agencies": "وكالات رياضية",
    "school research": "أبحاث مدرسية",
    "fiction organizations": "منظمات خيالية",
    "legal research": "أبحاث قانونية",
    "lgbtq-related organizations": "منظمات متعلقة بإل جي بي تي كيو",
    "science companies": "شركات علمية",
    "martial arts culture": "ثقافة فنون قتال",
    "music technology": "تقانة موسيقية",
    "school organisations": "منظمات مدرسية",
    "religious culture": "ثقافة دينية",
    "sound technology": "تقانة ناطقة",
    "sports occupations": "مهن رياضية",
    "sports organization": "منظمات رياضية",
    "western culture": "ثقافة غرب أمريكية",
    "anime companies": "شركات أنمي",
    "science technology": "تقانة علمية",
    "aviation culture": "ثقافة طيران",
    "aviation research": "أبحاث طيران",
    "sports industry": "صناعة رياضية",
    "christmas organizations": "منظمات عيد الميلاد",
    "war organizations": "منظمات حربية",
    "cyberpunk culture": "ثقافة سايبربانك",
    "dance culture": "ثقافة رقص",
    "dance occupations": "مهن رقص",
    "dance organisations": "منظمات رقص",
    "dance research": "أبحاث رقص",
    "astronomical research": "أبحاث فلكية",
    "school organization": "منظمات مدرسية",
    "interactive technology": "تقانة تفاعلية",
    "science organisations": "منظمات علمية",
    "fantasy organizations": "منظمات فانتازيا",
    "detective agencies": "وكالات مباحث",
    "historical agencies": "وكالات تاريخية",
    "historical organisations": "منظمات تاريخية",
    "martial arts organization": "منظمات فنون قتال",
    "lgbt culture": "ثقافة إل جي بي تي",
    "lgbt organisations": "منظمات إل جي بي تي",
    "lgbtq organization": "منظمات إل جي بي تي كيو",
    "maritime companies": "شركات بحرية",
    "aviation occupations": "مهن طيران",
    "action organizations": "منظمات حركة",
    "science industry": "صناعة علمية",
    "musical culture": "ثقافة موسيقية",
    "music organization": "منظمات موسيقية",
    "environment research": "أبحاث بيئية",
    "naval research": "أبحاث بحرية عسكرية",
    "political issues": "قضايا سياسية",
    "political occupations": "مهن سياسية",
    "science fiction culture": "ثقافة خيال علمي",
    "fiction culture": "ثقافة خيالية",
    "science fiction organizations": "منظمات خيال علمي",
    "science organization": "منظمات علمية",
    "sports technology": "تقانة رياضية",
    "children's research": "أبحاث أطفال",
    "television issues": "قضايا تلفزيونية",
    "television industry": "صناعة تلفزيونية",
    "television occupations": "مهن تلفزيونية",
    "reality companies": "شركات واقعية",
    "reality organizations": "منظمات واقعية",
    "nautical research": "أبحاث بحرية",
}

RELIGIOUS_FEMALE_KEYS: dict[str, str] = {
    "masonic": "ماسونية",
    "islamic": "إسلامية",
    "neopagan religious": "وثنية جديدة",
    "political party": "أحزاب سياسية",
    "jain": "جاينية",
    "new thought": "فكر جديد",
    "jewish": "يهودية",
    "protestant": "بروتستانتية",
    "sikh": "سيخية",
    "scientology": "سينتولوجيا",
    "spiritualist": "روحانية",
    "taoist": "طاوية",
    "buddhist": "بوذية",
    "unitarian universalist": "توحيدية عالمية",
    "hindu": "هندوسية",
    "christian": "مسيحية",
    "religious": "دينية",
    "zoroastrian": "زرادشتية",
    "bahá'í": "بهائية",
}

FEMALE_SUFFIXES: dict[str, str] = {
    "occupations": "مهن",
    "religious occupations": "مهن دينية",
    "academies": "أكاديميات",
    "agencies": "وكالات",
    "associations": "جمعيات",
    "awards": "جوائز",
    "bridge": "جسور",
    "buildings": "مبان",
    "bunkers": "مخابئ",
    "centers": "مراكز",
    "charities": "جمعيات خيرية",
    "children's charities": "جمعيات خيرية للأطفال",
    "clubs": "نوادي",
    "communities": "مجتمعات",
    "companies": "شركات",
    "consulting": "استشارات",
    "corporations": "مؤسسات تجارية",
    "culture": "ثقافة",
    "denominations": "طوائف",
    "disciplines": "تخصصات",
    "educational institutions": "هيئات تعليمية",
    "educational": "تعليمية",
    "facilities": "مرافق",
    "federations": "اتحادات",
    "festivals": "مهرجانات",
    "genital integrity": "سلامة الأعضاء التناسلية",
    "groups": "مجموعات",
    "ideologies": "أيديولوجيات",
    "installations": "منشآت",
    "institutions": "مؤسسات",
    "issues": "قضايا",
    "learned and professional societies": "جمعيات علمية ومهنية",
    "learned societies": "جمعيات علمية",
    "men's organizations": "منظمات رجالية",
    "movements and organisations": "حركات ومنظمات",
    "movements and organizations": "حركات ومنظمات",
    "movements": "حركات",
    "museums": "متاحف",
    "non-profit organizations": "منظمات غير ربحية",
    "non-profit publishers": "ناشرون غير ربحيون",
    "orders": "أخويات",
    "organisations": "منظمات",
    "organization": "منظمات",
    "organizations": "منظمات",
    "parks": "متنزهات",
    "pornography": "إباحية",
    "professional societies": "جمعيات مهنية",
    "religions": "ديانات",
    "religious orders": "أخويات دينية",
    "research": "أبحاث",
    "schools": "مدارس",
    "service organizations": "منظمات خدمية",
    "services": "خدمات",
    "societies": "جمعيات",
    "specialisms": "تخصصات",
    "student organizations": "منظمات طلابية",
    "utilities": "مرافق",
    "women's organizations": "منظمات نسائية",
    "youth organizations": "منظمات شبابية",
}

POP3_KEYS: dict[str, dict[str, str]] = {
    "healthcare": {"male": "", "female": "رعاية صحية"},
    "school": {"male": "", "female": "مدارس"},
    "theatres": {"male": "", "female": "مسارح"},
    "towers": {"male": "", "female": "أبراج"},
    "windmills": {"male": "", "female": "طواحين الهواء"},
    "veterans": {"male": "", "female": "قدامى المحاربين"},
    "transport": {"male": "", "female": "النقل"},
    "hotel": {"male": "", "female": "فنادق"},
    "fire": {"male": "", "female": "الإطفاء"},
    "major league baseball": {"male": "", "female": "دوري كرة القاعدة الرئيسي"},
    "veterans and descendants": {"male": "", "female": "أحفاد وقدامى المحاربين"},
    "transportation": {"male": "", "female": "نقل"},
    "shopping malls": {"male": "", "female": "مراكز تسوق"},
    "law enforcement": {"male": "", "female": "تطبيق القانون"},
    "dams": {"male": "", "female": "سدود"},
    "hospital": {"male": "", "female": "مستشفيات"},
    "airports": {"male": "", "female": "مطارات"},
    "casinos": {"male": "", "female": "كازينوهات"},
    "university and college": {"male": "", "female": "جامعات وكليات"},
    "colleges and universities": {"male": "", "female": "كليات وجامعات"},
    "university": {"male": "", "female": "جامعات"},
    "universities": {"male": "", "female": "جامعات"},
    "college": {"male": "", "female": "كليات"},
    "colleges": {"male": "", "female": "كليات"},
    "educational": {"male": "تعليمي", "female": "تعليمية"},
    "masonic": {"male": "ماسوني", "female": "ماسونية"},
    "office": {"male": "إداري", "female": "إدارية"},
    "religious": {"male": "ديني", "female": "دينية"},
    "residential": {"male": "سكني", "female": "سكنية"},
    "agricultural": {"male": "زراعي", "female": "زراعية"},
    "air defence": {"male": "دفاع جوي", "female": "دفاع جوية"},
    "anarchism": {"male": "لاسلطوي", "female": "لاسلطوية"},
    "anarchist": {"male": "لاسلطوي", "female": "لاسلطوية"},
    "anti-revisionist": {"male": "مناهض للتحريف", "female": "مناهضة للتحريفية"},
    "arts": {"male": "فني", "female": "فنية"},
    "astronomical": {"male": "فلكي", "female": "فلكية"},
    "chemical": {"male": "كيميائي", "female": "كيميائية"},
    "christian": {"male": "مسيحي", "female": "مسيحية"},
    "commercial": {"male": "تجاري", "female": "تجارية"},
    "constitutional": {"male": "دستوري", "female": "دستورية"},
    "consultative": {"male": "إستشاري", "female": "إستشارية"},
    "cultural": {"male": "ثقافي", "female": "ثقافية"},
    "defense": {"male": "دفاعي", "female": "دفاعية"},
    "economic": {"male": "اقتصادي", "female": "اقتصادية"},
    "environmental": {"male": "بيئي", "female": "بيئية"},
    "fraternal": {"male": "أخوي", "female": "أخوية"},
    "government": {"male": "حكومي", "female": "حكومية"},
    "industrial": {"male": "صناعي", "female": "صناعية"},
    "legal": {"male": "قانوني", "female": "قانونية"},
    "legislative": {"male": "تشريعي", "female": "تشريعية"},
    "logistics": {"male": "لوجستي", "female": "لوجستية"},
    "maritime": {"male": "بحري", "female": "بحرية"},
    "medical and health": {"male": "طبي وصحي", "female": "طبية وصحية"},
    "medical": {"male": "طبي", "female": "طبية"},
    "military": {"male": "عسكري", "female": "عسكرية"},
    "naval": {"male": "عسكرية بحري", "female": "عسكرية بحرية"},
    "paramilitary": {"male": "شبه عسكري", "female": "شبه عسكرية"},
    "political": {"male": "سياسي", "female": "سياسية"},
    "realist": {"male": "واقعي", "female": "واقعية"},
    "research": {"male": "بحثي", "female": "بحثية"},
    "strategy": {"male": "استراتيجي", "female": "استراتيجية"},
    "student": {"male": "طلابي", "female": "طلابية"},
    "training": {"male": "تدريبي", "female": "تدريبية"},
    "warfare": {"male": "حربي", "female": "حربية"},
    "youth": {"male": "شبابي", "female": "شبابية"},
}

FEMALE_EXPANSIONS: dict[str, str] = {
    "defunct {base} stations": "محطات {label} سابقة",
    "{base} ttelevision networks": "شبكات تلفزيونية {label}",
    "{base} television stations": "محطات تلفزيونية {label}",
    "{base} superfund sites": "مواقع استجابة بيئية شاملة {label}",
    "{base} stations": "محطات {label}",
    "{base} responses": "استجابات {label}",
    "{base} censorship": "رقابة {label}",
    "{base} communications": "اتصالات {label}",
    "{base} animals": "حيوانات {label}",
    "{base} philosophy": "فلسفة {label}",
    "{base} migration": "هجرة {label}",
    "{base} think tanks": "مؤسسات فكر ورأي {label}",
    "{base} positions": "مراكز {label}",
    "{base} accidents-and-incidents": "حوادث {label}",
    "{base} accidents and incidents": "حوادث {label}",
    "{base} accidents or incidents": "حوادث {label}",
    "{base} accidents": "حوادث {label}",
    "{base} incidents": "حوادث {label}",
    "{base} software": "برمجيات {label}",
    "{base} databases": "قواعد بيانات {label}",
    "{base} controversies": "خلافات {label}",
    "{base} agencies": "وكالات {label}",
    "{base} units and formations": "وحدات وتشكيلات {label}",
    "{base} squadrons‎": "أسراب {label}",
    "{base} ideologies": "أيديولوجيات {label}",
    "{base} occupations": "مهن {label}",
    "{base} organisations": "منظمات {label}",
    "{base} organizations": "منظمات {label}",
    "{base} organization": "منظمات {label}",
    "{base} facilities": "مرافق {label}",
    "{base} bunkers": "مخابئ {label}",
    "{base} research facilities": "مرافق بحثية {label}",
    "{base} training facilities": "مرافق تدريب {label}",
    "{base} industrial facilities": "مرافق صناعية {label}",
    "{base} warfare facilities": "مرافق حربية {label}",
    "{base} logistics": "لوجستية {label}",
    "{base} research": "أبحاث {label}",
    "{base} industry": "صناعة {label}",
    "{base} technology": "تقانة {label}",
    "{base} disasters": "كوارث {label}",
    "{base} writing": "كتابات {label}",
    "{base} issues": "قضايا {label}",
    "{base} rights": "حقوق {label}",
    "{base} communities": "مجتمعات {label}",
    "{base} culture": "ثقافة {label}",
    "{base} underground culture": "ثقافة باطنية {label}",
    "{base} companies of": "شركات {label} في",
    "{base} companies": "شركات {label}",
    "{base} firms of": "شركات {label} في",
    "{base} firms": "شركات {label}",
    "{base} museums": "متاحف {label}",
    "{base} politics": "سياسة {label}",
    "{base} banks": "بنوك {label}",
    "{base} buildings": "مبان {label}",
    "{base} structures": "منشآت {label}",
    "{base} installations": "منشآت {label}",
    "{base} building and structure": "مبان ومنشآت {label}",
    "{base} buildings and structures": "مبان ومنشآت {label}",
}


def build_female_keys() -> dict[str, str]:
    """Return the expanded mapping used for female-labelled categories."""
    data = {}
    for base, labels in POP3_KEYS.items():
        if labels.get("female"):
            lowered = base.lower()
            for template, translation in FEMALE_EXPANSIONS.items():
                data[template.format(base=lowered)] = translation.format(label=labels.get("female"))

    data.update(structures_data)
    data.update(companies_data)

    for suffix, translation in FEMALE_SUFFIXES.items():
        data[f"lgbt {suffix}"] = f"{translation} مثلية"
        data[f"secessionist {suffix}"] = f"{translation} انفصالية"
        data[f"defunct secessionist {suffix}"] = f"{translation} انفصالية سابقة"

    return data


New_female_keys: dict[str, str] = build_female_keys()
New_female_keys.update(films_data)

__all__ = [
    "New_female_keys",
    "RELIGIOUS_FEMALE_KEYS",
]

len_print.data_len(
    "female_keys.py",
    {
        "films_data": films_data,
        "New_female_keys": New_female_keys,
        "RELIGIOUS_FEMALE_KEYS": RELIGIOUS_FEMALE_KEYS,
        "religious_entries": religious_entries,
    },
)



"""
Tests
"""

import pytest

from ArWikiCats.new_resolvers.jobs_resolvers import resolve_jobs_main
from ArWikiCats.new_resolvers.nationalities_resolvers import resolve_nationalities_main
from ArWikiCats.new_resolvers.sports_resolvers import resolve_sports_main
from ArWikiCats.translations import countries_en_as_nationality_keys

test_data_must_be_empty = {
    "the caribbean": "",
    "caribbean": "",
}
test_data_must_be_empty.update({x: "" for x in countries_en_as_nationality_keys})


@pytest.mark.parametrize("category, expected_key", test_data_must_be_empty.items(), ids=test_data_must_be_empty.keys())
@pytest.mark.fast
def test_resolve_sports_main_must_be_empty(category: str, expected_key: str) -> None:
    label2 = resolve_sports_main(category)
    assert label2 == expected_key


@pytest.mark.parametrize("category, expected_key", test_data_must_be_empty.items(), ids=test_data_must_be_empty.keys())
@pytest.mark.fast
def test_resolve_nationalities_main_must_be_empty(category: str, expected_key: str) -> None:
    label2 = resolve_nationalities_main(category)
    assert label2 == expected_key


@pytest.mark.parametrize("category, expected_key", test_data_must_be_empty.items(), ids=test_data_must_be_empty.keys())
@pytest.mark.fast
def test_resolve_jobs_main_must_be_empty(category: str, expected_key: str) -> None:
    label2 = resolve_jobs_main(category)
    assert label2 == expected_key



"""
Tests
"""

import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats.legacy_bots.films_and_others_bot import te_films

fast_data_drama = {
    "english-language political drama films": "أفلام سياسية درامية باللغة الإنجليزية",
    "english-language war drama films": "أفلام حربية درامية باللغة الإنجليزية",
    "hindi-language drama films": "أفلام درامية باللغة الهندية",
    "norwegian-language romantic drama films": "أفلام رومانسية درامية باللغة النرويجية",
    "korean-language historical drama films": "أفلام تاريخية درامية باللغة الكورية",
    "portuguese-language biographical drama films": "أفلام سير ذاتية درامية باللغة البرتغالية",
    "russian-language fantasy drama films": "أفلام فانتازيا درامية باللغة الروسية",
    "spanish-language historical drama films": "أفلام تاريخية درامية باللغة الإسبانية",
}

fast_data = {
    "croatian biographical films": "أفلام سير ذاتية كرواتية",
    "albanian film directors": "مخرجو أفلام ألبان",
    "american film directors": "مخرجو أفلام أمريكيون",
    "argentine film actors": "ممثلو أفلام أرجنتينيون",
    "australian films": "أفلام أسترالية",
    "austrian films": "أفلام نمساوية",
    "british films": "أفلام بريطانية",
    "bruneian film producers": "منتجو أفلام برونيون",
    "czech silent film actors": "ممثلو أفلام صامتة تشيكيون",
    "czech-language crime films": "أفلام جريمة باللغة التشيكية",
    "dutch films": "أفلام هولندية",
    "english-language crime action films": "أفلام جريمة حركة باللغة الإنجليزية",
    "film directors": "مخرجو أفلام",
    "finnish-language erotic films": "أفلام إغرائية باللغة الفنلندية",
    "french films": "أفلام فرنسية",
    "french-language films": "أفلام باللغة الفرنسية",
    "german-language films": "أفلام باللغة الألمانية",
    "ghanaian films": "أفلام غانية",
    "hungarian-language romance films": "أفلام رومانسية باللغة المجرية",
    "indonesian film actresses": "ممثلات أفلام إندونيسيات",
    "iranian film actors": "ممثلو أفلام إيرانيون",
    "iranian film producers": "منتجو أفلام إيرانيون",
    "japanese films": "أفلام يابانية",
    "japanese male film actors": "ممثلو أفلام ذكور يابانيون",
    "japanese-language horror films": "أفلام رعب باللغة اليابانية",
    "kosovan filmmakers": "صانعو أفلام كوسوفيون",
    "latvian films": "أفلام لاتفية",
    "malayalam-language films": "أفلام باللغة الماليالامية",
    "maldivian women film directors": "مخرجات أفلام مالديفيات",
    "moldovan film actors": "ممثلو أفلام مولدوفيون",
    "moroccan musical films": "أفلام موسيقية مغربية",
    "nepalese male film actors": "ممثلو أفلام ذكور نيباليون",
    "nigerien film actors": "ممثلو أفلام نيجريون",
    "romanian films": "أفلام رومانية",
    "russian silent film actresses": "ممثلات أفلام صامتة روسيات",
    "russian-language historical comedy films": "أفلام تاريخية كوميدية باللغة الروسية",
    "saudiarabian films": "أفلام سعودية",
    "somalian film producers": "منتجو أفلام صوماليون",
    "soviet films": "أفلام سوفيتية",
    "spanish-language historical films": "أفلام تاريخية باللغة الإسبانية",
    "spanish-language sex comedy films": "أفلام جنسية كوميدية باللغة الإسبانية",
    "swedish-language musical films": "أفلام موسيقية باللغة السويدية",
    "telugu film directors": "مخرجو أفلام تيلوغويون",
    "thai film actors": "ممثلو أفلام تايلنديون",
    "ukrainian filmmakers": "صانعو أفلام أوكرانيون",
    "urdu-language films": "أفلام باللغة الأردية",
    "welsh film producers": "منتجو أفلام ويلزيون",
}


@pytest.mark.parametrize("category, expected", fast_data_drama.items(), ids=fast_data_drama.keys())
@pytest.mark.fast
def test_fast_data_drama(category: str, expected: str) -> None:
    label = te_films(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", fast_data.items(), ids=fast_data.keys())
@pytest.mark.fast
def test_fast_data_films(category: str, expected: str) -> None:
    label = te_films(category)
    assert label == expected


to_test = [
    ("test_fast_data_drama", fast_data_drama, te_films),
    ("test_fast_data_films", fast_data, te_films),
]


@pytest.mark.parametrize("name,data,callback", to_test)
@pytest.mark.dump
def test_peoples(name: str, data: dict[str, str], callback) -> None:
    expected, diff_result = one_dump_test(data, callback)

    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"


def test_test_films() -> None:
    # Test with a basic input
    result = te_films("action films")
    assert isinstance(result, str)

    result_empty = te_films("")
    assert isinstance(result_empty, str)

    # Test with reference category
    result_with_ref = te_films("drama movies")
    assert isinstance(result_with_ref, str)



#!/usr/bin/python3
"""
TODO: use this instead of nats_women.py
"""
import functools

from ...helps import logger
from ...translations import All_Nat, all_country_with_nat, all_country_with_nat_ar, countries_en_as_nationality_keys
from ...translations_formats import FormatDataV2
from ..nats_as_country_names import nats_keys_as_country_names
from .data import country_names_and_nats_data

countries_en_keys = [x.get("en") for x in all_country_with_nat.values() if x.get("en")]

formatted_data_double = {
    # "jewish {en} cuisine": "مطبخ {male} يهودي",
    # "jewish {en} history": "تاريخ {male} يهودي",
    # north american-jewish culture
    "{en} jewish surnames": "ألقاب يهودية {female}",
    "{en} jewish descent": "أصل يهودي {male}",
    "{en} jewish culture": "ثقافة يهودية {female}",
    "{en} jewish diaspora": "شتات يهودي {male}",
    "{en}-jewish surnames": "ألقاب يهودية {female}",
    "{en}-jewish descent": "أصل يهودي {male}",
    "{en}-jewish culture": "ثقافة يهودية {female}",
    "{en}-jewish diaspora": "شتات يهودي {male}",
}

peoples_nats_not_jobs_males = {
    "{en} expatriates": "{males} مغتربون",
    "{en} emigrants": "{males} مهاجرون",
    # "Category:Indonesian women singers": "تصنيف:مغنيات إندونيسيات",
    "{en} singers": "مغنون {males}",
    "{en} women singers": "مغنيات {females}",
}

males_data = {
    # en_is_nat_ar_is_mens
    "anti-{en} sentiment": "مشاعر معادية لل{males}",
    "{en} non profit publishers": "ناشرون غير ربحيون {males}",
    "{en} non-profit publishers": "ناشرون غير ربحيون {males}",
    "{en} government officials": "مسؤولون حكوميون {males}",
}

males_data.update(peoples_nats_not_jobs_males)

ar_data = {
    "{en} grand prix": "جائزة {ar} الكبرى",
    "{en} kings cup": "كأس ملك {ar}",  # Bahraini King's Cup
    "{en} cup": "كأس {ar}",
    "{en} independence": "استقلال {ar}",
    "{en} open": "{ar} المفتوحة",
    "{en} ladies open": "{ar} المفتوحة للسيدات",
    "{en} national university": "جامعة {ar} الوطنية",
    "{en} national university alumni": "خريجو جامعة {ar} الوطنية",
    "{en} national womens motorsports racing team": "منتخب {ar} لسباق رياضة المحركات للسيدات",
}

the_male_data = {
    "{en} nationality law": "قانون الجنسية {the_male}",
    "{en} executive council": "المجلس التنفيذي {the_male}",
    "{en} executive council positions": "مناصب في المجلس التنفيذي {the_male}",
    "former {en} executive council positions": "مناصب سابقة في المجلس التنفيذي {the_male}",
    # the_male - en_is_nat_ar_is_al_mens
    "{en} president cup": "كأس الرئيس {the_male}",
    "{en} federation cup": "كأس الاتحاد {the_male}",
    "{en} fa cup": "كأس الاتحاد {the_male}",
    "{en} occupation": "الاحتلال {the_male}",
    "{en} super cup": "كأس السوبر {the_male}",
    "{en} elite cup": "كأس النخبة {the_male}",
    "{en} referendum": "الاستفتاء {the_male}",
    "{en} involvement": "التدخل {the_male}",
    "{en} census": "التعداد {the_male}",
    "{en} professional football league": "دوري كرة القدم {the_male} للمحترفين",
    "{en} football premier league": "الدوري {the_male} الممتاز لكرة القدم",
    "{en} premier football league": "الدوري {the_male} الممتاز لكرة القدم",
    "{en} national super league": "دوري السوبر {the_male}",
    "{en} super league": "دوري السوبر {the_male}",
    "{en} premier league": "الدوري {the_male} الممتاز",
    "{en} premier division": "الدوري {the_male} الممتاز",
    "{en} amateur football league": "الدوري {the_male} لكرة القدم للهواة",
    "{en} football league": "الدوري {the_male} لكرة القدم",
    "{en} population census": "التعداد السكاني {the_male}",
    "{en} population and housing census": "التعداد {the_male} للسكان والمساكن",
    "{en} national party": "الحزب الوطني {the_male}",
    "{en} criminal law": "القانون الجنائي {the_male}",
    "{en} family law": "قانون الأسرة {the_male}",
    "{en} labour law": "قانون العمل {the_male}",
    "{en} abortion law": "قانون الإجهاض {the_male}",
    "{en} rugby union leagues": "اتحاد دوري الرجبي {the_male}",
    "{en} womens rugby union": "اتحاد الرجبي {the_male} للنساء",
    "{en} rugby union": "اتحاد الرجبي {the_male}",
    "{en} presidential pardons": "العفو الرئاسي {the_male}",
    "{en} pardons": "العفو {the_male}",
    # "professional football league": "الدوري {the_male} لكرة القدم للمحترفين",
}

male_data = {
    "{en} cuisine": "مطبخ {male}",
    "{en} history": "تاريخ {male}",
    # male - en_is_nat_ar_is_man
    # "{en} television": "تلفاز {male}",
    "{en} fiction": "خيال {male}",
    "{en} science": "علم {male}",
    "{en} diaspora": "شتات {male}",
    "{en} descent": "أصل {male}",
    "{en} military occupations": "احتلال عسكري {male}",
    "{en} integration": "تكامل {male}",
    "{en} innovation": "ابتكار {male}",
    "{en} design": "تصميم {male}",
    "{en} contemporary art": "فن معاصر {male}",
    "{en} art": "فن {male}",
    "{en} calendar": "تقويم {male}",
    "{en} non fiction literature": "أدب غير خيالي {male}",
    "{en} non-fiction literature": "أدب غير خيالي {male}",
    "{en} literature": "أدب {male}",
    "{en} caste system": "نظام طبقي {male}",
    "{en} law": "قانون {male}",
    "{en} wine": "نبيذ {male}",
    "{en} nuclear history": "تاريخ نووي {male}",
    "{en} military history": "تاريخ عسكري {male}",
    "{en} traditions": "تراث {male}",
    "{en} folklore": "فلكور {male}",
}

female_data_music = {
    "{en} youth music competitions": "منافسات موسيقية شبابية {female}",
    "{en} mixtape albums": "ألبومات ميكستايب {female}",
    "{en} mixtape music": "موسيقى ميكستايب {female}",
    "{en} music": "موسيقى {female}",
    "{en} music people": "شخصيات موسيقية {female}",
    "{en} music personalities": "شخصيات موسيقية {female}",
    "{en} musical duos": "فرق موسيقية ثنائية {female}",
    "{en} musical groups": "فرق موسيقية {female}",
    "{en} musical instruments": "آلات موسيقية {female}",
    "{en} youth sports competitions": "منافسات رياضية شبابية {female}",
    "{en} a cappella groups": "فرق أكابيلا {female}",
    "{en} a cappella musical groups": "فرق موسيقى أكابيلا {female}",
    "{en} alternative metal musical groups": "فرق موسيقى ميتال بديل {female}",
    "{en} alternative rock groups": "فرق روك بديل {female}",
    "{en} ambient music groups": "فرق موسيقى الأمبينت {female}",
    "{en} art punk groups": "فرق آرت بانك {female}",
    "{en} avant-garde metal musical groups": "فرق موسيقى ميتال أفانت جارد {female}",
    "{en} baroque music groups": "فرق موسيقى باروكية {female}",
    "{en} bhangra (music) musical groups": "فرق موسيقى بانغرا {female}",
    "{en} big beat groups": "فرق بيغ بيت {female}",
    "{en} bluegrass music groups": "فرق بلوغراس {female}",
    "{en} blues groups": "فرق بلوز {female}",
    "{en} blues rock groups": "فرق بلوز روك {female}",
    "{en} blues rock musical groups": "فرق موسيقى بلوز روك {female}",
    "{en} britpop groups": "فرق بوب بريطاني {female}",
    "{en} cantopop musical groups": "فرق موسيقى كانتوبوب {female}",
    "{en} celtic music groups": "فرق موسيقى كلتية {female}",
    "{en} celtic rock groups": "فرق روك سيلتي {female}",
    "{en} childrens musical groups": "فرق موسيقى أطفال {female}",
    "{en} christian punk groups": "فرق كريستيان بانك {female}",
    "{en} classical music groups": "فرق موسيقى كلاسيكية {female}",
    "{en} classical musical groups": "فرق موسيقى كلاسيكية {female}",
    "{en} comedy musical groups": "فرق موسيقى كوميديا {female}",
    "{en} contemporary folk music groups": "فرق موسيقى فلكلورية {female}",
    "{en} country groups": "فرق كانتري {female}",
    "{en} dance groups": "فرق رقص {female}",
    "{en} dance music groups": "فرق موسيقى الرقص {female}",
    "{en} dance musical groups": "فرق موسيقى رقص {female}",
    "{en} dance-pop groups": "فرق رقص البوب {female}",
    "{en} dancehall groups": "فرق دانسهول {female}",
    "{en} death metal musical groups": "فرق موسيقى ديث ميتال {female}",
    "{en} disco groups": "فرق ديسكو {female}",
    "{en} early music groups": "فرق موسيقى مبكرة {female}",
    "{en} electronic music groups": "فرق موسيقى إلكترونية {female}",
    "{en} electronic musical groups": "فرق موسيقى إليكترونيك {female}",
    "{en} electronic rock musical groups": "فرق موسيقى إليكترونيك روك {female}",
    "{en} emo musical groups": "فرق موسيقى إيمو {female}",
    "{en} eurodisco groups": "فرق يوروديسكو {female}",
    "{en} europop groups": "فرق يوروبوب {female}",
    "{en} experimental music groups": "فرق موسيقى تجريبية {female}",
    "{en} experimental musical groups": "فرق موسيقى تجريبية {female}",
    "{en} flamenco groups": "فرق فلامنكو {female}",
    "{en} folk groups": "فرق فولك {female}",
    "{en} folk musical groups": "فرق موسيقى فولك {female}",
    "{en} french hip hop groups": "فرق هيب هوب فرنسي {female}",
    "{en} funk groups": "فرق فانك {female}",
    "{en} fusion groups": "فرق فيوشن {female}",
    "{en} gangsta rap groups": "فرق راب العصابات {female}",
    "{en} glam metal musical groups": "فرق موسيقى جلام ميتال {female}",
    "{en} gospel music groups": "فرق غوسبل {female}",
    "{en} gospel musical groups": "فرق موسيقى غوسبل {female}",
    "{en} gothic music groups": "فرق موسيقى غوثك {female}",
    "{en} gothic rock groups": "فرق غوثك روك {female}",
    "{en} grindcore musical groups": "فرق موسيقى قريندكور {female}",
    "{en} grunge groups": "فرق غرنج {female}",
    "{en} grunge musical groups": "فرق موسيقى غرنج {female}",
    "{en} hard rock musical groups": "فرق موسيقى هارد روك {female}",
    "{en} hardcore punk groups": "فرق هاردكور بانك {female}",
    "{en} hip hop musical groups": "فرق موسيقى هيب هوب {female}",
    "{en} horrorcore groups": "فرق هورور كور {female}",
    "{en} house groups": "فرق الهاوس {female}",
    "{en} house music groups": "فرق هاوس {female}",
    "{en} indie folk groups": "فرق إندي فولك {female}",
    "{en} indie music groups": "فرق موسيقى إندي {female}",
    "{en} indie rock musical groups": "فرق موسيقى إيندي روك {female}",
    "{en} industrial groups": "فرق صناعية {female}",
    "{en} industrial rock musical groups": "فرق موسيقى إندستريال روك {female}",
    "{en} klezmer groups": "فرق كليزمر {female}",
    "{en} latin music groups": "فرق موسيقى لاتينية {female}",
    "{en} mandopop musical groups": "فرق موسيقى ماندوبوب {female}",
    "{en} mariachi groups": "فرق مرياتي {female}",
    "{en} metal groups": "فرق ميتال {female}",
    "{en} minimal music groups": "فرق موسيقى حد أدنى {female}",
    "{en} music groups": "فرق موسيقى {female}",
    "{en} música popular brasileira musical groups": "فرق موسيقى شعبية برازيلية {female}",
    "{en} new wave groups": "فرق موجة جديدة {female}",
    "{en} new wave musical groups": "فرق موسيقى موجة جديدة {female}",
    "{en} new-age music groups": "فرق موسيقى العصر الجديد {female}",
    "{en} noise musical groups": "فرق موسيقى ضوضائية {female}",
    "{en} nu metal musical groups": "فرق موسيقى نيو ميتال {female}",
    "{en} opera groups": "فرق أوبرا {female}",
    "{en} peruvian cumbia musical groups": "فرق موسيقى كومبيا بيروفية {female}",
    "{en} political music groups": "فرق موسيقى سياسية {female}",
    "{en} polka groups": "فرق بولكا {female}",
    "{en} pop musical groups": "فرق موسيقى بوب {female}",
    "{en} pop punk groups": "فرق بوب بانك {female}",
    "{en} pop-rap groups": "فرق بوب راب {female}",
    "{en} post-grunge groups": "فرق بوست-غرنج {female}",
    "{en} post-grunge musical groups": "فرق موسيقى بوست-غرنج {female}",
    "{en} post-punk groups": "فرق بوست بانك {female}",
    "{en} post-punk musical groups": "فرق موسيقى بوست بانك {female}",
    "{en} power metal musical groups": "فرق موسيقى باور ميتال {female}",
    "{en} progressive metal musical groups": "فرق موسيقى بروجريسف ميتال {female}",
    "{en} punk blues musical groups": "فرق موسيقى بانك بلوز {female}",
    "{en} punk music groups": "فرق موسيقى بانك {female}",
    "{en} qawwali groups": "فرق قوالي {female}",
    "{en} r&b groups": "فرق ريذم أند بلوز {female}",
    "{en} r&b musical groups": "فرق موسيقى ريذم أند بلوز {female}",
    "{en} rap groups": "فرق راب {female}",
    "{en} rap metal musical groups": "فرق موسيقى راب ميتال {female}",
    "{en} rapcore groups": "فرق راب كور {female}",
    "{en} reggaeton groups": "فرق ريغيه تون {female}",
    "{en} rhythm and blues musical groups": "فرق موسيقى ريذم أند بلوز {female}",
    "{en} rock musical groups": "فرق موسيقى روك {female}",
    "{en} romani groups": "فرق غجرية {female}",
    "{en} romani musical groups": "فرق موسيقى غجرية {female}",
    "{en} ska musical groups": "فرق موسيقى سكا {female}",
    "{en} soul music groups": "فرق موسيقى السول {female}",
    "{en} soul musical groups": "فرق موسيقى السول {female}",
    "{en} southern hip hop groups": "فرق هيب هوب جنوبي {female}",
    "{en} swing music groups": "فرق سوينغ {female}",
    "{en} swing musical groups": "فرق موسيقى سوينغ {female}",
    "{en} symphonic black metal musical groups": "فرق موسيقى بلاك ميتال سمفوني {female}",
    "{en} symphonic metal musical groups": "فرق موسيقى ميتال سيمفوني {female}",
    "{en} synth-pop groups": "فرق سينثبوب {female}",
    "{en} technical death metal musical groups": "فرق موسيقى ديث ميتال الفني {female}",
    "{en} techno groups": "فرق تكنو {female}",
    "{en} teen pop groups": "فرق بوب الشباب {female}",
    "{en} tejano music groups": "فرق موسيقى تيخانو {female}",
    "{en} traditional musical groups": "فرق موسيقى تقليدية {female}",
    "{en} trance musical groups": "فرق موسيقى ترانس {female}",
    "{en} west coast hip hop groups": "فرق هيب هوب الساحل الغربي {female}",
    "{en} christian communities": "مجتمعات مسيحية {female}",
    "{en} christian metal musical groups": "فرق موسيقى ميتال مسيحي {female}",
    "{en} christian rock groups": "فرق روك مسيحي {female}",
    "{en} alternative metal groups": "فرق ميتال بديل {female}",
    "{en} bibliographies": "ببليوجرافيات {female}",
    "{en} conferences": "مؤتمرات {female}",
    "{en} contemporary r&b groups": "فرق آر أند بي معاصر {female}",
    "{en} metal musical groups": "فرق موسيقى ميتال {female}",
    "{en} music awards": "جوائز موسيقى {female}",
    "{en} pop groups": "فرق بوب {female}",
    "{en} rhythm and blues groups": "فرق ريذم أند بلوز {female}",
    "{en} socialist organizations": "منظمات اشتراكية {female}",
    "{en} black metal musical groups": "فرق موسيقى بلاك ميتال {female}",
    "{en} blues musical groups": "فرق موسيقى بلوز {female}",
    "{en} contemporary r&b musical groups": "فرق موسيقى آر أند بي معاصر {female}",
    "{en} country music groups": "فرق كانتري {female}",
    "{en} doom metal musical groups": "فرق موسيقى دوم ميتال {female}",
    "{en} electronic dance music groups": "فرق موسيقى الرقص الإلكترونية {female}",
    "{en} eurodance groups": "فرق يورودانس {female}",
    "{en} folk music groups": "فرق موسيقى تقليدية {female}",
    "{en} folk rock groups": "فرق فولك روك {female}",
    "{en} funk musical groups": "فرق موسيقى فانك {female}",
    "{en} gothic metal musical groups": "فرق موسيقى غوثيك ميتال {female}",
    "{en} heavy metal musical groups by genre": "فرق موسيقى هيفي ميتال {female} حسب النوع الفني",
    "{en} heavy metal musical groups": "فرق موسيقى هيفي ميتال {female}",
    "{en} hip hop groups": "فرق هيب هوب {female}",
    "{en} hip-hop groups": "فرق هيب هوب {female}",
    "{en} indie pop groups": "فرق إيندي بوب {female}",
    "{en} indie rock groups": "فرق إيندي روك {female}",
    "{en} musicals": "مسرحيات غنائية {female}",
    "{en} pop music groups": "فرق موسيقى بوب {female}",
    "{en} reggae musical groups": "فرق موسيقى ريغيه {female}",
    "{en} rock music groups": "فرق موسيقى الروك {female}",
    "{en} ska groups": "فرق سكا {female}",
    "{en} thrash metal musical groups": "فرق موسيقى ثراش ميتال {female}",
    "{en} world music groups": "فرق موسيقى العالم {female}",
}

female_data = {
    "{en} miniseries": "مسلسلات قصيرة {female}",
    "{en} tennis commentators": "معلقو كرة مضرب {female}",
    "{en} international schools": "مدارس دولية {female}",
    "{en} childrens books": "كتب أطفال {female}",
    "{en} hindu festivals": "مهرجانات هندوسية {female}",
    "{en} documentaries": "وثائقيات {female}",
    "{en} cookbooks": "كتب طبخ {female}",
    "{en} political websites": "مواقع ويب سياسية {female}",
    "{en} comic": "قصص مصورة {female}",
    "{en} organized crime": "جريمة منظمة {female}",
    "{en} paintings": "لوحات {female}",
    "{en} online encyclopedias": "موسوعات إنترنت {female}",
    "{en} architecture awards": "جوائز عمارة {female}",
    "{en} childrens magazines": "مجلات أطفال {female}",
    "{en} ethnic groups": "مجموعات عرقية {female}",
    "{en} feminist organizations": "منظمات نسوية {female}",
    "{en} illuminated manuscripts": "مخطوطات مذهبة {female}",
    "{en} manuscripts": "مخطوطات {female}",
    "{en} medical organizations": "منظمات طبية {female}",
    "{en} military units and formations": "وحدات وتشكيلات عسكرية {female}",
    "{en} new religious movements": "حركات دينية جديدة {female}",
    "{en} political movements": "حركات سياسية {female}",
    "{en} religious movements": "حركات دينية {female}",
    "{en} biographical dictionaries": "قواميس سير ذاتية {female}",
    "{en} cultural organizations": "منظمات ثقافية {female}",
    "{en} buddhist temples": "معابد بوذية {female}",
    # "Christian religious orders by century of establishment": "أخويات دينية مسيحية حسب قرن التأسيس",
    "{en} religious orders": "أخويات دينية {female}",
    # "Christian political parties": "أحزاب سياسية مسيحية",
    "{en} political parties": "أحزاب سياسية {female}",
    "{en} texts": "نصوص {female}",
    "{en} events": "أحداث {female}",
    "{en} political organizations": "منظمات سياسية {female}",
    "{en} rock groups": "فرق روك {female}",
    "{en} history organizations": "منظمات تاريخ {female}",
    "{en} religious organizations": "منظمات دينية {female}",
    "{en} Islamic organisations": "منظمات إسلامية {female}",
    "{en} islamic organizations": "منظمات إسلامية {female}",
    # "Category:1972 in American women's sports": "تصنيف:رياضة أمريكية للسيدات في 1972",
    "{en} sports": "ألعاب رياضية {female}",
    "{en} womens sports": "رياضات نسائية {female}",
    "burial sites of {en} noble families": "مواقع دفن عائلات نبيلة {female}",
    "burial sites of {en} royal houses": "مواقع دفن بيوت ملكية {female}",
    "{en} video game businesspeople": "شخصيات أعمال {female} في ألعاب الفيديو",
    "{en} video game industry businesspeople": "شخصيات أعمال {female} في صناعة ألعاب الفيديو",
    "{en} real estate businesspeople": "شخصيات أعمال {female} في العقارات",
    "{en} real estate industry businesspeople": "شخصيات أعمال {female} في صناعة العقارات",
    "{en} metals businesspeople": "شخصيات أعمال {female} في المعادن",
    "{en} metals industry businesspeople": "شخصيات أعمال {female} في صناعة المعادن",
    "{en} financial industry businesspeople": "شخصيات أعمال {female} في صناعة المالية",
    "{en} financial businesspeople": "شخصيات أعمال {female} في المالية",
    "{en} fashion businesspeople": "شخصيات أعمال {female} في الأزياء",
    "{en} fashion industry businesspeople": "شخصيات أعمال {female} في صناعة الأزياء",
    "{en} entertainment businesspeople": "شخصيات أعمال {female} في الترفيه",
    "{en} cosmetics businesspeople": "شخصيات أعمال {female} في مستحضرات التجميل",
    "{en} cosmetics industry businesspeople": "شخصيات أعمال {female} في صناعة مستحضرات التجميل",
    "{en} computer industry businesspeople": "شخصيات أعمال {female} في صناعة كمبيوتر",
    "{en} computer businesspeople": "شخصيات أعمال {female} في الكمبيوتر",
    "{en} entertainment industry businesspeople": "شخصيات أعمال {female} في صناعة الترفيه",
    "{en} non-fiction comic strips": "شرائط كومكس {female} غير خيالية",
    "{en} non-fiction comic": "قصص مصورة {female} غير خيالية",
    "{en} non-fiction comics": "قصص مصورة {female} غير خيالية",
    "{en} non-fiction crime": "جريمة {female} غير خيالية",
    "{en} non-fiction graphic novels": "روايات مصورة {female} غير خيالية",
    "{en} non-fiction novels": "روايات {female} غير خيالية",
    # female - en_is_nat_ar_is_women
    "{en} non-fiction books": "كتب {female} غير خيالية",
    "{en} non fiction books": "كتب {female} غير خيالية",
    "{en} books": "كتب {female}",
    "{en} phonologies": "تصريفات صوتية {female}",
    "{en} crimes": "جرائم {female}",
    "{en} crimes against humanity": "جرائم ضد الإنسانية {female}",
    "{en} war crimes": "جرائم حرب {female}",
    "{en} airstrikes": "ضربات جوية {female}",
    "deaths by {en} airstrikes": "وفيات بضربات جوية {female}",
    "{en} archipelagoes": "أرخبيلات {female}",
    "{en} architecture": "عمارة {female}",
    "{en} autobiographies": "ترجمة ذاتية {female}",
    "{en} automotive": "سيارات {female}",
    "{en} awards and decorations": "جوائز وأوسمة {female}",
    "{en} awards": "جوائز {female}",
    "{en} ballot measures": "إجراءات اقتراع {female}",
    "{en} ballot propositions": "اقتراحات اقتراع {female}",
    "{en} border crossings": "معابر حدودية {female}",
    "{en} border": "حدود {female}",
    "{en} brands": "ماركات {female}",
    "{en} budgets": "موازنات {female}",
    "{en} buildings": "مباني {female}",
    "{en} business culture": "ثقافة مالية {female}",
    "{en} businesspeople": "شخصيات أعمال {female}",
    "{en} cantons": "كانتونات {female}",
    "{en} casualties": "خسائر {female}",
    "{en} cathedrals": "كاتدرائيات {female}",
    "{en} championships": "بطولات {female}",
    "{en} civil awards and decorations": "جوائز وأوسمة مدنية {female}",
    "{en} classical albums": "ألبومات كلاسيكية {female}",
    "{en} classical music": "موسيقى كلاسيكية {female}",
    "{en} clothing": "ملابس {female}",
    "{en} clubs": "أندية {female}",
    "{en} coats of arms": "شعارات نبالة {female}",
    "{en} colonial": "مستعمرات {female}",
    "{en} comedy albums": "ألبومات كوميدية {female}",
    "{en} comedy music": "موسيقى كوميدية {female}",
    "{en} comedy": "كوميديا {female}",
    "{en} companies": "شركات {female}",
    "{en} competitions": "منافسات {female}",
    "{en} compilation albums": "ألبومات تجميعية {female}",
    "{en} countries": "بلدان {female}",
    "{en} culture": "ثقافة {female}",
    "{en} decorations": "أوسمة {female}",
    "{en} diplomatic missions": "بعثات دبلوماسية {female}",
    "{en} discoveries": "اكتشافات {female}",
    "{en} drink": "مشروبات {female}",
    "{en} elections": "انتخابات {female}",
    "{en} encyclopedias": "موسوعات {female}",
    "{en} executions": "إعدامات {female}",
    "{en} explosions": "انفجارات {female}",
    "{en} families": "عائلات {female}",
    "{en} fauna": "حيوانات {female}",
    "{en} festivals": "مهرجانات {female}",
    "{en} folk albums": "ألبومات فلكلورية {female}",
    "{en} folk music": "موسيقى فلكلورية {female}",
    "{en} folklore characters": "شخصيات فلكلورية {female}",
    "{en} football club matches": "مباريات أندية كرة قدم {female}",
    "{en} football club seasons": "مواسم أندية كرة قدم {female}",
    "{en} forests": "غابات {female}",
    "{en} gangs": "عصابات {female}",
    "{en} given names": "أسماء شخصية {female}",
    "{en} heraldry": "نبالة {female}",
    "{en} heritage sites": "موقع تراث عالمي {female}",
    "{en} inscriptions": "نقوش {female}",
    "{en} introductions": "استحداثات {female}",
    "{en} inventions": "اختراعات {female}",
    "{en} islands": "جزر {female}",
    "{en} issues": "قضايا {female}",
    "{en} jewellery": "مجوهرات {female}",
    "{en} journalism": "صحافة {female}",
    "{en} lakes": "بحيرات {female}",
    "{en} learned and professional societies": "جمعيات علمية ومهنية {female}",
    "{en} learned societies": "جمعيات علمية {female}",
    "{en} literary awards": "جوائز أدبية {female}",
    "{en} magazines": "مجلات {female}",
    "{en} mascots": "تمائم {female}",
    "{en} masculine given names": "أسماء ذكور {female}",
    "{en} media personalities": "شخصيات إعلامية {female}",
    "{en} media": "وسائل إعلام {female}",
    "{en} memoirs": "مذكرات {female}",
    "{en} memorials and cemeteries": "نصب تذكارية ومقابر {female}",
    "{en} military equipment": "معدات عسكرية {female}",
    "{en} military terminology": "مصطلحات عسكرية {female}",
    "{en} military-equipment": "معدات عسكرية {female}",
    "{en} military-terminology": "مصطلحات عسكرية {female}",
    "{en} mixtape albums": "ألبومات ميكستايب {female}",
    "{en} mixtape music": "موسيقى ميكستايب {female}",
    "{en} monarchy": "ملكية {female}",
    "{en} motorsport": "رياضة محركات {female}",
    "{en} mountains": "جبال {female}",
    "{en} movies": "أفلام {female}",
    "{en} music people": "شخصيات موسيقية {female}",
    "{en} music personalities": "شخصيات موسيقية {female}",
    "{en} music": "موسيقى {female}",
    "{en} musical duos": "فرق موسيقية ثنائية {female}",
    "{en} musical groups": "فرق موسيقية {female}",
    "{en} musical instruments": "آلات موسيقية {female}",
    "{en} mythology": "أساطير {female}",
    "{en} phonology": "نطقيات {female}",
    "{en} names": "أسماء {female}",
    "{en} nationalism": "قومية {female}",
    "{en} newspapers": "صحف {female}",
    "{en} non-profit organizations": "منظمات غير ربحية {female}",
    "{en} non profit organizations": "منظمات غير ربحية {female}",
    "{en} novels": "روايات {female}",
    "{en} online journalism": "صحافة إنترنت {female}",
    "{en} operas": "أوبيرات {female}",
    "{en} organisations": "منظمات {female}",
    "{en} organizations": "منظمات {female}",
    "{en} parishes": "أبرشيات {female}",
    "{en} parks": "متنزهات {female}",
    "{en} peoples": "شعوب {female}",
    "{en} philosophy": "فلسفة {female}",
    "{en} plays": "مسرحيات {female}",
    "{en} poems": "قصائد {female}",
    "{en} political philosophy": "فلسفة سياسية {female}",
    "{en} popular culture": "ثقافة شعبية {female}",
    "{en} professional societies": "جمعيات مهنية {female}",
    "{en} provinces": "مقاطعات {female}",
    "{en} publications": "منشورات {female}",
    "{en} radio networks": "شبكات مذياع {female}",
    "{en} radio stations": "محطات إذاعية {female}",
    "{en} radio": "راديو {female}",
    "{en} rebellions": "تمردات {female}",
    "{en} occupations": "مهن {female}",
    "{en} religious occupations": "مهن دينية {female}",
    "{en} rectors": "عمدات {female}",
    "{en} referendums": "استفتاءات {female}",
    "{en} religions": "ديانات {female}",
    "{en} resorts": "منتجعات {female}",
    "{en} restaurants": "مطاعم {female}",
    "{en} revolutions": "ثورات {female}",
    "{en} riots": "أعمال شغب {female}",
    "{en} road cycling": "سباقات دراجات على الطريق {female}",
    "{en} roads": "طرقات {female}",
    "{en} royal families": "عائلات ملكية {female}",
    "{en} schools and colleges": "مدارس وكليات {female}",
    "{en} sculptures": "منحوتات {female}",
    "{en} sea temples": "معابد بحرية {female}",
    "{en} short stories": "قصص قصيرة {female}",
    "{en} societies": "جمعيات {female}",
    "{en} songs": "أغاني {female}",
    "{en} sports-events": "أحداث رياضية {female}",
    "{en} soundtracks": "موسيقى تصويرية {female}",
    "{en} sport": "رياضة {female}",
    "{en} sports competitions": "منافسات رياضية {female}",
    "{en} sports events": "أحداث رياضية {female}",
    "{en} surnames": "ألقاب {female}",
    "{en} swamps": "مستنقعات {female}",
    "{en} telenovelas": "تيلينوفيلا {female}",
    "{en} film series": "سلاسل أفلام {female}",
    "{en} television commercials": "إعلانات تجارية تلفزيونية {female}",
    "{en} television films": "أفلام تلفزيونية {female}",
    "{en} television miniseries": "مسلسلات قصيرة تلفزيونية {female}",
    "{en} television networks": "شبكات تلفزيونية {female}",
    "{en} television news": "أخبار تلفزيونية {female}",
    "{en} television personalities": "شخصيات تلفزيونية {female}",
    "{en} television programmes": "برامج تلفزيونية {female}",
    "{en} television programs": "برامج تلفزيونية {female}",
    "{en} television series": "مسلسلات تلفزيونية {female}",
    "non {en} television series": "مسلسلات تلفزيونية غير {female}",
    "non-{en} television series": "مسلسلات تلفزيونية غير {female}",
    "{en} television series-debuts": "مسلسلات تلفزيونية {female} بدأ عرضها في",
    "{en} television series-endings": "مسلسلات تلفزيونية {female} انتهت في",
    "{en} television stations": "محطات تلفزيونية {female}",
    "{en} television-seasons": "مواسم تلفزيونية {female}",
    "{en} temples": "معابد {female}",
    "{en} tennis": "كرة مضرب {female}",
    "{en} terminology": "مصطلحات {female}",
    "{en} titles": "ألقاب {female}",
    "{en} tour": "بطولات {female}",
    "{en} towns": "بلدات {female}",
    "{en} trains": "قطارات {female}",
    "{en} trials": "محاكمات {female}",
    "{en} tribes": "قبائل {female}",
    "{en} underground culture": "ثقافة باطنية {female}",
    "{en} universities": "جامعات {female}",
    "{en} verbs": "أفعال {female}",
    "{en} video games": "ألعاب فيديو {female}",
    "{en} volcanoes": "براكين {female}",
    "{en} wars": "حروب {female}",
    "{en} waterfalls": "شلالات {female}",
    "{en} webcomic": "ويب كومكس {female}",
    "{en} webcomics": "ويب كومكس {female}",
    "{en} websites": "مواقع ويب {female}",
    "{en} womens sport": "رياضة {female} نسائية",
    "{en} works": "أعمال {female}",
    "{en} youth competitions": "منافسات شبابية {female}",
    "{en} youth music competitions": "منافسات موسيقية شبابية {female}",
    "{en} youth sports competitions": "منافسات رياضية شبابية {female}",
}

female_data.update(female_data_music)

burial_sites = {
    "{en} dynasties": "أسر {female}",
    "ancient {en} dynasties": "أسر {female} قديمة",
    "{en} imperial dynasties": "أسر إمبراطورية {female}",
    "{en} noble families": "عائلات نبيلة {female}",
    "{en} royal houses": "بيوت ملكية {female}",
    "imperial {en} families": "أسر إمبراطورية {female}",
}
female_data.update(burial_sites)

female_data.update({f"burial sites of {k}": f"مواقع دفن {v}" for k, v in burial_sites.items()})

the_female_data = {
    "{en} concentration camps": "معسكرات الاعتقال {the_female}",
    "{en} film awards": "جوائز الأفلام {the_female}",
    "{en} film award": "جوائز الأفلام {the_female}",
    "{en} film award winners": "فائزون بجائزة الأفلام {the_female}",
    "{en} short film awards": "جوائز الأفلام القصيرة {the_female}",
    "{en} airways accidents and incidents": "حوادث الخطوط الجوية {the_female}",
    "{en} airways accidents-and-incidents": "حوادث الخطوط الجوية {the_female}",
    "{en} airways": "الخطوط الجوية {the_female}",
    "{en} youth games": "الألعاب {the_female} الشبابية",
    "{en} financial crisis": "الأزمة المالية {the_female}",
    "{en} presidential crisis": "الأزمة الرئاسية {the_female}",
    "{en} military academy": "الأكاديمية العسكرية {the_female}",
    "{en} military college": "الكلية العسكرية {the_female}",
    "{en} crisis": "الأزمة {the_female}",
    "{en} energy crisis": "أزمة الطاقة {the_female}",
    "{en} constitutional crisis": "الأزمة الدستورية {the_female}",
    "{en} games competitors": "منافسون في الألعاب {the_female}",
    "{en} games medalists": "فائزون بميداليات الألعاب {the_female}",
    "{en} games gold medalists": "فائزون بميداليات ذهبية في الألعاب {the_female}",
    "{en} games silver medalists": "فائزون بميداليات فضية في الألعاب {the_female}",
    "{en} games bronze medalists": "فائزون بميداليات برونزية في الألعاب {the_female}",
    "{en} television people": "شخصيات التلفزة {the_female}",
    "{en} legislative election": "الانتخابات التشريعية {the_female}",
    "{en} parliamentary election": "الانتخابات البرلمانية {the_female}",
    "{en} regional election": "انتخابات الإقليمية {the_female}",
    "{en} vice-presidential election": "انتخابات نائب الرئاسة {the_female}",
    # baston_women: dict[str, str] = {
    "{en} movement": "الحركة {the_female}",
    "{en} unity cup": "كأس الوحدة {the_female}",
    "{en} rail": "السكك الحديدية {the_female}",
    "{en} television": "التلفزة {the_female}",
    "{en} revolution": "الثورة {the_female}",
    "{en} war": "الحرب {the_female}",
    "{en} border war": "حرب الحدود {the_female}",
    "{en} detention": "المعتقلات {the_female}",
    "{en} para games": "الألعاب البارالمبية {the_female}",
    "{en} games": "الألعاب {the_female}",
    "{en} medical association": "الجمعية الطبية {the_female}",
    "{en} soccer": "كرة القدم {the_female}",
    "{en} cinema": "السينما {the_female}",
    "{en} politics": "السياسة {the_female}",
    # female - military_format_women_without_al
    "{en} federal legislation": "تشريعات فيدرالية {female}",
    "{en} courts": "محاكم {female}",
    "{en} sports templates": "قوالب رياضة {female}",
    "{en} political party": "أحزاب سياسية {female}",
    # "society" : "الجمعية {the_female}",
    "{en} presidential primarie": "الانتخابات الرئاسية التمهيدية {the_female}",
    "{en} presidential primaries": "الانتخابات الرئاسية التمهيدية {the_female}",
}

all_formatted_data = (
    males_data
    | ar_data
    | the_male_data
    | male_data
    | the_female_data
    | country_names_and_nats_data
    | female_data  # | formatted_data_double
)


@functools.lru_cache(maxsize=1)
def _load_bot() -> FormatDataV2:
    nats_data = {
        # x: v for x, v in all_country_with_nat_ar.items()  # if v.get("ar")
        x: v
        for x, v in All_Nat.items()  # if v.get("ar")
    }
    nats_data.update({x: v for x, v in nats_keys_as_country_names.items()})  # if v.get("ar")

    if "jewish-american" not in nats_data:
        print(nats_data.keys())

    return FormatDataV2(
        formatted_data=all_formatted_data,
        data_list=nats_data,
        key_placeholder="{en}",
        text_before="the ",
    )


def fix_keys(category: str) -> str:
    """Fix known issues in category keys before searching.

    Args:
        category: The original category key.
    """
    # Fix specific known issues with category keys
    category = category.lower().replace("category:", "")
    category = category.replace("'", "")
    return category.strip()


@functools.lru_cache(maxsize=10000)
def resolve_by_nats(category: str) -> str:
    logger.debug(f"<<yellow>> start resolve_by_nats: {category=}")

    if category in countries_en_as_nationality_keys or category in countries_en_keys:
        logger.info(f"<<yellow>> skip resolve_by_nats: {category=}, [result=]")
        return ""
    category = fix_keys(category)
    nat_bot = _load_bot()
    result = nat_bot.search_all_category(category)
    logger.info_if_or_debug(f"<<yellow>> end resolve_by_nats: {category=}, {result=}", result)
    return result


__all__ = [
    "resolve_by_nats",
]



"""Unit tests"""

import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats import resolve_arabic_category_label

test_1 = {
    "Category:Wheelchair basketball": "تصنيف:كرة السلة على الكراسي المتحركة",
}

wheelchair_by_nats = {
    "Category:Spanish men's wheelchair basketball players": "تصنيف:لاعبو كرة سلة على كراسي متحركة إسبان",
    "Category:Swiss men's wheelchair basketball players": "تصنيف:لاعبو كرة سلة على كراسي متحركة سويسريون",
    "Category:Turkish men's wheelchair basketball players": "تصنيف:لاعبو كرة سلة على كراسي متحركة أتراك",
    "Category:Swiss Wheelchair Curling Championship": "تصنيف:بطولة سويسرا للكيرلنغ على الكراسي المتحركة",
    "Category:European Wheelchair Basketball Championship": "تصنيف:بطولة أوروبا لكرة السلة على الكراسي المتحركة",
    "Category:Parapan American Games medalists in wheelchair basketball": "تصنيف:فائزون بميداليات ألعاب بارابان الأمريكية في كرة السلة على الكراسي المتحركة",
    "Category:Parapan American Games medalists in wheelchair tennis": "تصنيف:فائزون بميداليات ألعاب بارابان الأمريكية في كرة المضرب على الكراسي المتحركة",
    "Category:Parapan American Games wheelchair basketball players": "تصنيف:لاعبو كرة سلة على كراسي متحركة في ألعاب بارابان الأمريكية",
    "Category:Parapan American Games wheelchair rugby players": "تصنيف:لاعبو رجبي على كراسي متحركة في ألعاب بارابان الأمريكية",
    "Category:Parapan American Games wheelchair tennis players": "تصنيف:لاعبو كرة مضرب على كراسي متحركة في ألعاب بارابان الأمريكية",
    "Category:Russian wheelchair curlers": "تصنيف:لاعبو كيرلنغ على الكراسي المتحركة روس",
    "Category:Scottish wheelchair curlers": "تصنيف:لاعبو كيرلنغ على الكراسي المتحركة إسكتلنديون",
    "Category:Scottish wheelchair curling champions": "تصنيف:أبطال الكيرلنغ على الكراسي المتحركة إسكتلنديون",
    "Category:Slovak wheelchair curlers": "تصنيف:لاعبو كيرلنغ على الكراسي المتحركة سلوفاكيون",
    "Category:South Korean wheelchair curlers": "تصنيف:لاعبو كيرلنغ على الكراسي المتحركة كوريون جنوبيون",
    "Category:Spanish wheelchair basketball players": "تصنيف:لاعبو كرة سلة على كراسي متحركة إسبان",
    "Category:Spanish wheelchair fencers": "تصنيف:مبارزون على الكراسي المتحركة إسبان",
    "Category:Spanish wheelchair tennis players": "تصنيف:لاعبو كرة مضرب على كراسي متحركة إسبان",
    "Category:Swedish wheelchair curlers": "تصنيف:لاعبو كيرلنغ على الكراسي المتحركة سويديون",
    "Category:Swedish wheelchair curling champions": "تصنيف:أبطال الكيرلنغ على الكراسي المتحركة سويديون",
    "Category:Swedish wheelchair tennis players": "تصنيف:لاعبو كرة مضرب على كراسي متحركة سويديون",
    "Category:Swiss wheelchair basketball players": "تصنيف:لاعبو كرة سلة على كراسي متحركة سويسريون",
    "Category:Swiss wheelchair curlers": "تصنيف:لاعبو كيرلنغ على الكراسي المتحركة سويسريون",
    "Category:Swiss wheelchair curling champions": "تصنيف:أبطال الكيرلنغ على الكراسي المتحركة سويسريون",
    "Category:Swiss wheelchair tennis players": "تصنيف:لاعبو كرة مضرب على كراسي متحركة سويسريون",
    "Category:Thai wheelchair tennis players": "تصنيف:لاعبو كرة مضرب على كراسي متحركة تايلنديون",
    "Category:Turkish wheelchair basketball players": "تصنيف:لاعبو كرة سلة على كراسي متحركة أتراك",
    "Category:Turkish wheelchair tennis players": "تصنيف:لاعبو كرة مضرب على كراسي متحركة أتراك",
    "Category:Turkish women's wheelchair basketball players": "تصنيف:لاعبات كرة سلة على كراسي متحركة تركيات",
    "Category:Welsh wheelchair curlers": "تصنيف:لاعبو كيرلنغ على الكراسي المتحركة ويلزيون",
}


wheelchair_basketball = {
    "Category:Wheelchair basketball at the 2020 Parapan American Games": "تصنيف:كرة السلة على الكراسي المتحركة في ألعاب بارابان الأمريكية 2020",
    "Category:Wheelchair basketball at the 2020 Summer Paralympics": "تصنيف:كرة السلة على الكراسي المتحركة في الألعاب البارالمبية الصيفية 2020",
    "Category:Wheelchair basketball at the Asian Para Games": "تصنيف:كرة السلة على الكراسي المتحركة في الألعاب البارالمبية الآسيوية",
    "Category:Wheelchair basketball at the Parapan American Games": "تصنيف:كرة السلة على الكراسي المتحركة في ألعاب بارابان الأمريكية",
    "Category:Wheelchair basketball at the Summer Paralympics": "تصنيف:كرة السلة على الكراسي المتحركة في الألعاب البارالمبية الصيفية",
    "Category:Wheelchair basketball by country": "تصنيف:كرة السلة على الكراسي المتحركة حسب البلد",
    "Category:Wheelchair basketball by year": "تصنيف:كرة السلة على الكراسي المتحركة حسب السنة",
    "Category:Wheelchair basketball coaches": "تصنيف:مدربو كرة سلة على كراسي متحركة",
    "Category:Wheelchair basketball competitions between national teams": "تصنيف:منافسات كرة سلة على كراسي متحركة بين منتخبات وطنية",
    "Category:Wheelchair basketball competitions in Europe": "تصنيف:منافسات كرة سلة على كراسي متحركة في أوروبا",
    "Category:Wheelchair basketball competitions": "تصنيف:منافسات كرة سلة على كراسي متحركة",
    "Category:Wheelchair basketball in Australia": "تصنيف:كرة السلة على الكراسي المتحركة في أستراليا",
    "Category:Wheelchair basketball in Cameroon": "تصنيف:كرة السلة على الكراسي المتحركة في الكاميرون",
    "Category:Wheelchair basketball in Canada": "تصنيف:كرة السلة على الكراسي المتحركة في كندا",
    "Category:Wheelchair basketball in China": "تصنيف:كرة السلة على الكراسي المتحركة في الصين",
    "Category:Wheelchair basketball in France": "تصنيف:كرة السلة على الكراسي المتحركة في فرنسا",
    "Category:Wheelchair basketball in Germany": "تصنيف:كرة السلة على الكراسي المتحركة في ألمانيا",
    "Category:Wheelchair basketball in Israel": "تصنيف:كرة السلة على الكراسي المتحركة في إسرائيل",
    "Category:Wheelchair basketball in Japan": "تصنيف:كرة السلة على الكراسي المتحركة في اليابان",
    "Category:Wheelchair basketball in Kuwait": "تصنيف:كرة السلة على الكراسي المتحركة في الكويت",
    "Category:Wheelchair basketball in New Zealand": "تصنيف:كرة السلة على الكراسي المتحركة في نيوزيلندا",
    "Category:Wheelchair basketball in Poland": "تصنيف:كرة السلة على الكراسي المتحركة في بولندا",
    "Category:Wheelchair basketball in South Korea": "تصنيف:كرة السلة على الكراسي المتحركة في كوريا الجنوبية",
    "Category:Wheelchair basketball in Spain": "تصنيف:كرة السلة على الكراسي المتحركة في إسبانيا",
    "Category:Wheelchair basketball in Switzerland": "تصنيف:كرة السلة على الكراسي المتحركة في سويسرا",
    "Category:Wheelchair basketball in Thailand": "تصنيف:كرة السلة على الكراسي المتحركة في تايلاند",
    "Category:Wheelchair basketball in the Netherlands": "تصنيف:كرة السلة على الكراسي المتحركة في هولندا",
    "Category:Wheelchair basketball in the Philippines": "تصنيف:كرة السلة على الكراسي المتحركة في الفلبين",
    "Category:Wheelchair basketball in the United Kingdom": "تصنيف:كرة السلة على الكراسي المتحركة في المملكة المتحدة",
    "Category:Wheelchair basketball in the United States": "تصنيف:كرة السلة على الكراسي المتحركة في الولايات المتحدة",
    "Category:Wheelchair basketball in Turkey": "تصنيف:كرة السلة على الكراسي المتحركة في تركيا",
}


wheelchair_sports = {
    "Category:Wheelchair basketball leagues in Australia": "تصنيف:دوريات كرة السلة على الكراسي المتحركة في أستراليا",
    "Category:Wheelchair basketball leagues in Europe": "تصنيف:دوريات كرة السلة على الكراسي المتحركة في أوروبا",
    "Category:Wheelchair basketball leagues": "تصنيف:دوريات كرة سلة على كراسي متحركة",
    "Category:Wheelchair basketball players at the 2020 Parapan American Games": "تصنيف:لاعبو كرة سلة على كراسي متحركة في ألعاب بارابان الأمريكية 2020",
    "Category:Wheelchair basketball players at the 2020 Summer Paralympics": "تصنيف:لاعبو كرة سلة على كراسي متحركة في الألعاب البارالمبية الصيفية 2020",
    "Category:Wheelchair basketball players by nationality": "تصنيف:لاعبو كرة سلة على كراسي متحركة حسب الجنسية",
    "Category:Wheelchair basketball players in Turkey by team": "تصنيف:لاعبو كرة سلة على كراسي متحركة في تركيا حسب الفريق",
    "Category:Wheelchair basketball players": "تصنيف:لاعبو كرة سلة على كراسي متحركة",
    "Category:Wheelchair basketball teams by country": "تصنيف:فرق كرة السلة على الكراسي المتحركة حسب البلد",
    "Category:Wheelchair basketball teams in Greece": "تصنيف:فرق كرة السلة على الكراسي المتحركة في اليونان",
    "Category:Wheelchair basketball teams in Spain": "تصنيف:فرق كرة السلة على الكراسي المتحركة في إسبانيا",
    "Category:Wheelchair basketball teams in Turkey": "تصنيف:فرق كرة السلة على الكراسي المتحركة في تركيا",
    "Category:Wheelchair basketball teams": "تصنيف:فرق كرة سلة على كراسي متحركة",
    "Category:Wheelchair basketball templates": "تصنيف:قوالب كرة سلة على كراسي متحركة",
    "Category:Wheelchair basketball terminology": "تصنيف:مصطلحات كرة سلة على كراسي متحركة",
    "Category:Wheelchair basketball venues in Turkey": "تصنيف:ملاعب كرة السلة على الكراسي المتحركة في تركيا",
    "Category:Wheelchair Basketball World Championship": "تصنيف:بطولة العالم لكرة السلة على الكراسي المتحركة",
    "Category:Wheelchair curlers at the 2020 Winter Paralympics": "تصنيف:لاعبو كيرلنغ على الكراسي المتحركة في الألعاب البارالمبية الشتوية 2020",
    "Category:Wheelchair curlers by nationality": "تصنيف:لاعبو كيرلنغ على الكراسي المتحركة حسب الجنسية",
    "Category:Wheelchair curlers": "تصنيف:لاعبو كيرلنغ على الكراسي المتحركة",
    "Category:Wheelchair curling at the 2020 Winter Paralympics": "تصنيف:الكيرلنغ على الكراسي المتحركة في الألعاب البارالمبية الشتوية 2020",
    "Category:Wheelchair curling at the Winter Paralympics": "تصنيف:الكيرلنغ على الكراسي المتحركة في الألعاب البارالمبية الشتوية",
    "Category:Wheelchair curling": "تصنيف:الكيرلنغ على الكراسي المتحركة",
    "Category:Wheelchair discus throwers": "تصنيف:رماة قرص على الكراسي المتحركة",
    "Category:Wheelchair fencers at the 2020 Summer Paralympics": "تصنيف:مبارزون على الكراسي المتحركة في الألعاب البارالمبية الصيفية 2020",
    "Category:Wheelchair fencers": "تصنيف:مبارزون على الكراسي المتحركة",
    "Category:Wheelchair fencing at the 2020 Summer Paralympics": "تصنيف:مبارزة سيف الشيش على الكراسي المتحركة في الألعاب البارالمبية الصيفية 2020",
    "Category:Wheelchair fencing at the Summer Paralympics": "تصنيف:مبارزة سيف الشيش على الكراسي المتحركة في الألعاب البارالمبية الصيفية",
    "Category:Wheelchair fencing": "تصنيف:مبارزة سيف الشيش على الكراسي المتحركة",
    "Category:Wheelchair handball competitions": "تصنيف:منافسات كرة يد على كراسي متحركة",
    "Category:Wheelchair handball": "تصنيف:كرة اليد على الكراسي المتحركة",
    "Category:Wheelchair racing at the Summer Olympics": "تصنيف:سباق الكراسي المتحركة في الألعاب الأولمبية الصيفية",
    "Category:Wheelchair racing": "تصنيف:سباق الكراسي المتحركة",
    "Category:Wheelchair rugby at the 2020 Parapan American Games": "تصنيف:الرجبي على الكراسي المتحركة في ألعاب بارابان الأمريكية 2020",
    "Category:Wheelchair rugby at the 2020 Summer Paralympics": "تصنيف:الرجبي على الكراسي المتحركة في الألعاب البارالمبية الصيفية 2020",
    "Category:Wheelchair rugby at the 2020 World Games": "تصنيف:الرجبي على الكراسي المتحركة في دورة الألعاب العالمية 2020",
    "Category:Wheelchair rugby at the Parapan American Games": "تصنيف:الرجبي على الكراسي المتحركة في ألعاب بارابان الأمريكية",
    "Category:Wheelchair rugby at the Summer Paralympics": "تصنيف:الرجبي على الكراسي المتحركة في الألعاب البارالمبية الصيفية",
    "Category:Wheelchair rugby at the World Games": "تصنيف:الرجبي على الكراسي المتحركة في دورة الألعاب العالمية",
    "Category:Wheelchair rugby coaches": "تصنيف:مدربو رجبي على كراسي متحركة",
    "Category:Wheelchair rugby competitions": "تصنيف:منافسات رجبي على كراسي متحركة",
    "Category:Wheelchair rugby people": "تصنيف:أعلام رجبي على كراسي متحركة",
    "Category:Wheelchair rugby players at the 2020 Parapan American Games": "تصنيف:لاعبو رجبي على كراسي متحركة في ألعاب بارابان الأمريكية 2020",
    "Category:Wheelchair rugby players at the 2020 Summer Paralympics": "تصنيف:لاعبو رجبي على كراسي متحركة في الألعاب البارالمبية الصيفية 2020",
    "Category:Wheelchair rugby players by nationality": "تصنيف:لاعبو رجبي على كراسي متحركة حسب الجنسية",
    "Category:Wheelchair rugby players": "تصنيف:لاعبو رجبي على كراسي متحركة",
    "Category:Wheelchair rugby templates": "تصنيف:قوالب رجبي على كراسي متحركة",
    "Category:Wheelchair rugby": "تصنيف:الرجبي على الكراسي المتحركة",
    "Category:Wheelchair tennis at the 2020 Parapan American Games": "تصنيف:كرة المضرب على الكراسي المتحركة في ألعاب بارابان الأمريكية 2020",
    "Category:Wheelchair tennis at the 2020 Summer Paralympics": "تصنيف:كرة المضرب على الكراسي المتحركة في الألعاب البارالمبية الصيفية 2020",
    "Category:Wheelchair tennis at the Asian Para Games": "تصنيف:كرة المضرب على الكراسي المتحركة في الألعاب البارالمبية الآسيوية",
    "Category:Wheelchair tennis at the Parapan American Games": "تصنيف:كرة المضرب على الكراسي المتحركة في ألعاب بارابان الأمريكية",
    "Category:Wheelchair tennis at the Summer Paralympics": "تصنيف:كرة المضرب على الكراسي المتحركة في الألعاب البارالمبية الصيفية",
    "Category:Wheelchair tennis in Spain": "تصنيف:كرة المضرب على الكراسي المتحركة في إسبانيا",
    "Category:Wheelchair tennis players at the 2020 Asian Para Games": "تصنيف:لاعبو كرة مضرب على كراسي متحركة في الألعاب البارالمبية الآسيوية 2020",
    "Category:Wheelchair tennis players at the 2020 Parapan American Games": "تصنيف:لاعبو كرة مضرب على كراسي متحركة في ألعاب بارابان الأمريكية 2020",
    "Category:Wheelchair tennis players at the 2020 Summer Paralympics": "تصنيف:لاعبو كرة مضرب على كراسي متحركة في الألعاب البارالمبية الصيفية 2020",
    "Category:Wheelchair tennis players": "تصنيف:لاعبو كرة مضرب على كراسي متحركة",
    "Category:Wheelchair tennis tournaments": "تصنيف:بطولات كرة مضرب على كراسي متحركة",
    "Category:Wheelchair tennis": "تصنيف:كرة المضرب على الكراسي المتحركة",
    "Category:Women's wheelchair basketball players by nationality": "تصنيف:لاعبات كرة سلة على كراسي متحركة حسب الجنسية",
    "Category:Women's wheelchair basketball players": "تصنيف:لاعبات كرة سلة على كراسي متحركة",
    "Category:World wheelchair curling champions": "تصنيف:أبطال العالم للكيرلنغ على الكراسي المتحركة",
    "Category:Years in wheelchair rugby": "تصنيف:سنوات في الرجبي على الكراسي المتحركة",
}

TEMPORAL_CASES = [
    ("test_wheelchair_by_nats", wheelchair_by_nats),
    ("test_wheelchair_basketball", wheelchair_basketball),
    ("test_wheelchair_sports", wheelchair_sports),
]


@pytest.mark.parametrize("category, expected", test_1.items(), ids=test_1.keys())
@pytest.mark.fast
def test_wheelchair_first(category: str, expected: str) -> None:
    label = resolve_arabic_category_label(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", wheelchair_by_nats.items(), ids=wheelchair_by_nats.keys())
@pytest.mark.fast
def test_wheelchair_by_nats(category: str, expected: str) -> None:
    label = resolve_arabic_category_label(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", wheelchair_basketball.items(), ids=wheelchair_basketball.keys())
@pytest.mark.fast
def test_wheelchair_basketball(category: str, expected: str) -> None:
    label = resolve_arabic_category_label(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", wheelchair_sports.items(), ids=wheelchair_sports.keys())
@pytest.mark.fast
def test_wheelchair_sports(category: str, expected: str) -> None:
    label = resolve_arabic_category_label(category)
    assert label == expected


@pytest.mark.parametrize("name,data", TEMPORAL_CASES)
@pytest.mark.dump
def test_all(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_arabic_category_label)

    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



#
import pytest
from load_one_data import dump_diff, dump_same_and_not_same, one_dump_test

from ArWikiCats import resolve_label_ar

fast_data_1 = {
    "April 2020 sports events France": "",
    "ASEAN sports events": "",
    "Cancelled sports events": "",
    "Cancelled sports events by sport": "",
    "Charity sports events": "",
    "Current sports events": "",
    "International sports events": "",
    "LGBTQ sports events": "",
    "Qualification for sports events": "",
    "Red Bull sports events": "",
    "Scheduled sports events": "",
    "Shooting sports events": "",
    "Sports events affected by the COVID-19 pandemic": "",
    "Sports events affected by the Russian invasion of Ukraine": "",
    "Sports events affected by the September 11 attacks": "",
    "Sports events at Caesars Palace": "",
    "Sports events at MGM Grand Garden Arena": "",
    "Sports events at Wembley Stadium": "",
    "Sports events by venue": "",
    "Sports events external link templates": "",
    "Sports events founded by Sri Chinmoy": "",
    "Sports events music": "",
    "Sports events official songs and anthems": "",
}

fast_data_2 = {}

fast_data_3 = {
    "Lists of sports events": "قوائم أحداث رياضية",
    "Lists of sports events in Australia": "قوائم أحداث رياضية في أستراليا",
    "Lists of American sports events": "قوائم أحداث رياضية أمريكية",
    "Lists of announcers of American sports events": "قوائم مذيعون من أحداث رياضية أمريكية",
    "Lists of Taiwanese sports events": "قوائم أحداث رياضية تايوانية",
    "Men's sports events by continent": "أحداث رياضية رجالية حسب القارة",
    "Men's sports events in Africa": "أحداث رياضية رجالية في إفريقيا",
    "Men's sports events in Asia": "أحداث رياضية رجالية في آسيا",
    "Men's sports events in Europe": "أحداث رياضية رجالية في أوروبا",
    "Men's sports events in North America": "أحداث رياضية رجالية في أمريكا الشمالية",
    "Men's sports events in Oceania": "أحداث رياضية رجالية في أوقيانوسيا",
    "Men's sports events": "أحداث رياضية رجالية",
    "Sports events by continent": "أحداث رياضية حسب القارة",
    "Sports events by sport": "أحداث رياضية حسب الرياضة",
    "Sports events navigational boxes": "صناديق تصفح أحداث رياضية",
    "Sports events templates": "قوالب أحداث رياضية",
    "Sports events": "أحداث رياضية",
    "Women's sports events by continent": "أحداث رياضية نسائية حسب القارة",
    "Women's sports events in Africa": "أحداث رياضية نسائية في إفريقيا",
    "Women's sports events in Asia": "أحداث رياضية نسائية في آسيا",
    "Women's sports events in Europe": "أحداث رياضية نسائية في أوروبا",
    "Women's sports events in North America": "أحداث رياضية نسائية في أمريكا الشمالية",
    "Women's sports events in Oceania": "أحداث رياضية نسائية في أوقيانوسيا",
    "Women's sports events in South America": "أحداث رياضية نسائية في أمريكا الجنوبية",
    "Women's sports events": "أحداث رياضية نسائية",
}

to_test = [
    ("test_sports_events_2", fast_data_2),
    ("test_sports_events_3", fast_data_3),
]


@pytest.mark.parametrize("category, expected", fast_data_2.items(), ids=fast_data_2.keys())
@pytest.mark.fast
def test_1(category: str, expected: str) -> None:
    label = resolve_label_ar(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", fast_data_3.items(), ids=fast_data_3.keys())
@pytest.mark.fast
def test_2(category: str, expected: str) -> None:
    label = resolve_label_ar(category)
    assert label == expected


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.dump
def test_peoples(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_label_ar)

    dump_diff(diff_result, name)
    dump_same_and_not_same(data, diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



"""Tests for the player and singer job datasets."""

from __future__ import annotations

from ArWikiCats.translations.jobs.jobs_womens import (
    short_womens_jobs,
)


def test_female_jobs_include_film_and_sport_variants() -> None:
    """Female-specific roles should include derived movie and sport categories."""

    assert "sportswomen" in short_womens_jobs
    assert "film actresses" in short_womens_jobs
    assert short_womens_jobs["sportswomen"] == "رياضيات"
    assert short_womens_jobs["film actresses"].startswith("ممثلات")



"""
Tests
"""

import pytest
from load_one_data import dump_diff, dump_same_and_not_same, one_dump_test

from ArWikiCats.legacy_bots.ma_bots.lab_seoo_bot import event_label_work

event_Lab_seoo_data = {
    "100th united states congress": "الكونغرس الأمريكي المئة",
    "101st united states congress": "الكونغرس الأمريكي الأول بعد المئة",
    "102nd united states congress": "الكونغرس الأمريكي الثاني بعد المئة",
    "103rd united states congress": "الكونغرس الأمريكي الثالث بعد المئة",
    "104th united states congress": "الكونغرس الأمريكي الرابع بعد المئة",
    "105th united states congress": "الكونغرس الأمريكي الخامس بعد المئة",
    "106th united states congress": "الكونغرس الأمريكي السادس بعد المئة",
    "107th united states congress": "الكونغرس الأمريكي السابع بعد المئة",
    "108th united states congress": "الكونغرس الأمريكي الثامن بعد المئة",
    "109th united states congress": "الكونغرس الأمريكي التاسع بعد المئة",
    "10th united states congress": "الكونغرس الأمريكي العاشر",
    "110th united states congress": "الكونغرس الأمريكي العاشر بعد المئة",
    "111th united states congress": "الكونغرس الأمريكي الحادي عشر بعد المئة",
    "112th united states congress": "الكونغرس الأمريكي الثاني عشر بعد المئة",
    "113th united states congress": "الكونغرس الأمريكي الثالث عشر بعد المئة",
    "114th united states congress": "الكونغرس الأمريكي الرابع عشر بعد المئة",
    "115th united states congress": "الكونغرس الأمريكي الخامس عشر بعد المئة",
    "116th united states congress": "الكونغرس الأمريكي السادس عشر بعد المئة",
    "117th united states congress": "الكونغرس الأمريكي السابع عشر بعد المئة",
    "118th united states congress": "الكونغرس الأمريكي الثامن عشر بعد المئة",
    "119th united states congress": "الكونغرس الأمريكي التاسع عشر بعد المئة",
    "11th united states congress": "الكونغرس الأمريكي الحادي عشر",
    "12th united states congress": "الكونغرس الأمريكي الثاني عشر",
    "13th united states congress": "الكونغرس الأمريكي الثالث عشر",
    "14th united states congress": "الكونغرس الأمريكي الرابع عشر",
    "15th united states congress": "الكونغرس الأمريكي الخامس عشر",
    "16th united states congress": "الكونغرس الأمريكي السادس عشر",
    "1830 alabama": "ألاباما 1830",
    "1830 arkansas": "أركنساس 1830",
    "1830 connecticut": "كونيتيكت 1830",
    "1830 delaware": "ديلاوير 1830",
    "1830 florida territory": "إقليم فلوريدا 1830",
    "1830 georgia (u.s. state)": "ولاية جورجيا 1830",
    "1830 illinois": "إلينوي 1830",
    "1830 indiana territory": "إقليم إنديانا 1830",
    "1830 indiana": "إنديانا 1830",
    "1830 iowa territory": "إقليم آيوا 1830",
    "1830 kentucky": "كنتاكي 1830",
    "1830 louisiana": "لويزيانا 1830",
    "1830 maine": "مين 1830",
    "1830 maryland": "ماريلند 1830",
    "1830 massachusetts": "ماساتشوستس 1830",
    "1830 michigan territory": "إقليم ميشيغان 1830",
    "1830 michigan": "ميشيغان 1830",
    "1830 mississippi territory": "إقليم مسيسيبي 1830",
    "1830 mississippi": "مسيسيبي 1830",
    "1830 missouri": "ميزوري 1830",
    "1830 new hampshire": "نيوهامشير 1830",
    "1830 new jersey": "نيوجيرسي 1830",
    "1830 new york (state)": "ولاية نيويورك 1830",
    "1830 north carolina": "كارولاينا الشمالية 1830",
    "1830 ohio": "أوهايو 1830",
    "1830 pennsylvania": "بنسلفانيا 1830",
    "1830 rhode island": "رود آيلاند 1830",
    "1830 south carolina": "كارولاينا الجنوبية 1830",
    "1830 tennessee": "تينيسي 1830",
    "1830 trabzon": "طرابزون 1830",
    "1830 vermont": "فيرمونت 1830",
    "1830 virginia": "فرجينيا 1830",
    "1830 wisconsin territory": "إقليم ويسكونسن 1830",
}


@pytest.mark.parametrize("category, expected_key", event_Lab_seoo_data.items(), ids=event_Lab_seoo_data.keys())
@pytest.mark.fast
def test_event_Lab_seoo_data(category: str, expected_key: str) -> None:
    label = event_label_work(category)
    assert label == expected_key


to_test = [
    ("test_lab_seoo_bot_1", event_Lab_seoo_data),
]


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.dump
def test_peoples(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, event_label_work)
    dump_same_and_not_same(data, diff_result, name)
    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



#!/usr/bin/python3
""" """

from ..helps import len_print

SUPPLEMENTARY_LANGUAGE_TRANSLATIONS = {
    "herero": "هيريرو",
    "hiri motu": "هيري موتو",
    "ido": "إيدو",
    "igbo": "إيجبو",
    "interlingua": "إنترلنغوا",
    # "yoruba" : "يوربا",
    "zhuang": "زهيونج",
    "interlingue": "إنترلينج",
    "inupiaq": "إينبياك",
    "kikuyu": "كيكيو",
    "kinyarwanda": "كينيارواندا",
    "kuanyama": "كيونياما",
    "lingala": "لينغالا",
    "luba-katanga": "تشيلوبا",
    "navajo": "نافاجو",
    "ndonga": "ندونجا",
    "odia": "أوريا",
    "quechua": "كتشوا",
    "shona": "شونا",
    "swati": "سوازي",
    "twi": "توي",
    "nyanja": "نيانجا",
    "aymara": "أيمارا",
    "bashkir": "باشقير",
    "chuvash": "تشوفاش",
    "divehi": "ديفهي",
    "dzongkha": "دزونكا",
    "ganda": "جاندا",
    "esperanto": "إسبرانتو",
}

language_key_translations = {}

PRIMARY_LANGUAGE_TRANSLATIONS = {
    "balinese": "بالية",
    "pali": "بالية",
    "abkhazian": "أبخازية",
    "afar": "عفارية",
    # "afrikaans":"أفريقانية",
    "afrikaans": "إفريقية",
    "uralic": "أورالية",
    "akan": "أكانية",
    "albanian": "ألبانية",
    "alemannic": "أليمانية",
    "amharic": "أمهرية",
    "semitic": "سامية",
    "afroasiatic": "أفروآسيوية",
    "arabic": "عربية",
    "aragonese": "أرغونية",
    "armenian": "أرمنية",
    "assamese": "آسامية",
    "asturian": "أستورية",
    "avaric": "أوارية",
    "avestan": "أفستية",
    "azerbaijani": "أذربيجانية",
    # "azerbaijani":"أذرية",
    "bambara": "بمبرية",
    "bangla": "بنغالية",
    "bashkir": "باشقورية",
    "basque": "باسكية",
    # "basque":"بشكنشية",
    "belarusian": "بيلاروسية",
    "bengali": "بنغالية",
    "bhojpuri": "بهارية",
    "bishnupriya manipuri": "بيشنوبريا مانيبورية",
    "bislama": "بسلاما",
    "bosniak": "بوشناقية",
    "bosnian": "بوسنية",
    "breton": "بريتانية",
    "bulgarian": "بلغارية",
    "burmese": "بورمية",
    "cantonese": "كانتونية",
    "catalan": "كتلانية",
    "chamorro": "تسمورية",
    "chechen": "شيشانية",
    "chinese": "صينية",
    "chuvash": "تشوفاشيا",
    "classical syriac": "سريانية",
    "cornish": "كورنية",
    "corsican": "كورسيكية",
    "cree": "كرية",
    "croatian": "كرواتية",
    "czech": "تشيكية",
    "danish": "دنماركية",
    "dutch": "هولندية",
    "egyptian arabic": "مصرية",
    "english": "إنجليزية",
    "esperanto": "إسبرانتو",
    "estonian": "إستونية",
    "ewe": "إوية",
    "faroese": "فاروية",
    "fijian": "فيجية",
    "finnish": "فنلندية",
    "french": "فرنسية",
    "fulah": "فولانية",
    "galician": "جليقية",
    "georgian": "جورجية",
    "german": "ألمانية",
    "germanic": "جرمانية",
    "greek": "يونانية",
    "guarani": "غوارانية",
    "gujarati": "غوجاراتية",
    "hausa": "هوسية",
    "hebrew": "عبرية",
    "hindustani": "هندوستانية",
    "hindi": "هندية",
    "hungarian": "مجرية",
    "icelandic": "آيسلندية",
    "ido": "إيدوية",
    "indonesian": "إندونيسية",
    "inuktitut": "إنكتيتوتية",
    "irish": "أيرلندية",
    "italian": "إيطالية",
    "japanese": "يابانية",
    "javanese": "جاوية",
    "judaeo-spanish": "لادينو",
    "kalaallisut": "جرينلاندية",
    "kannada": "كنادية",
    "kanuri": "كانورية",
    "kashmiri": "كشميرية",
    "kazakh": "كازاخية",
    "khmer": "خميرية",
    "kinyarwanda": "روندية",
    "komi": "كومية",
    "kongo": "كونغو",
    "korean": "كورية",
    "kurdish": "كردية",
    "kyrgyz": "قيرغيزية",
    "lao": "لاوية",
    "latin": "لاتينية",
    "aramaic": "آرامية",
    "latvian": "لاتفية",
    "limburgish": "ليمبورغية",
    "lithuanian": "لتوانية",
    "luxembourgish": "لوكسمبورغية",
    "macedonian": "مقدونية",
    "malagasy": "ملغاشية",
    "malay": "ملايوية",
    "malayalam": "ماليالامية",
    "maltese": "مالطية",
    "manx": "منكية",
    "maori": "ماورية",
    "marathi": "ماراثية",
    "marshallese": "مارشالية",
    "mongolian": "منغولية",
    "nauru": "ناورونية",
    "neapolitan": "نابولية",
    "nepal bhasa": "نيوارية",
    "nepali": "نيبالية",
    "norwegian": "نرويجية",
    "occitan": "أکسيتانية",
    "ojibwa": "أوجيبوا",
    "oromo": "أورومية",
    "ossetic": "أوسيتية",
    "pashto": "بشتوية",
    "indo-european": "هندو أوروبية",
    "persian": "فارسية",
    "piedmontese": "بيدمونتية",
    "polish": "بولندية",
    "portuguese": "برتغالية",
    "punjabi": "بنجابية",
    "ripuarian": "ريبوارية",
    "romanian": "رومانية",
    "romansh": "رومانشية",
    "rundi": "كيروندية",
    "russian": "روسية",
    "samoan": "ساموية",
    "samogitian": "ساموجيتية",
    "sango": "سانغوية",
    "sanskrit": "سنسكريتية",
    "sardinian": "سردينية",
    "scots": "إسكتلندية",
    "serbian": "صربية",
    "serbo-croatian": "صربوكرواتية",
    "sichuan yi": "نؤوسوية",
    "sicilian": "صقلية",
    "silesian": "سيليسية",
    "sindhi": "سندية",
    "sinhala": "سنهالية",
    "slovak": "سلوفاكية",
    "slovene": "سلوفينية",
    "slovenian": "سلوفينية",
    "somali": "صومالية",
    "southern sotho": "سوتية",
    "spanish": "إسبانية",
    "sundanese": "سوندية",
    "swahili": "سواحلية",
    "swedish": "سويدية",
    "tagalog": "تاغالوغية",
    "tahitian": "تاهيتية",
    "tajik": "طاجيكية",
    "tamil": "تاميلية",
    "tatar": "تترية",
    "telugu": "تيلوغوية",
    "thai": "تايلندية",
    "tibetan": "تبتية",
    "tigrinya": "تغرينية",
    "tongan": "تونغية",
    "tsonga": "تسونجا",
    "tswana": "تسوانية",
    "turkish": "تركية",
    "turkmen": "تركمانية",
    "ukrainian": "أوكرانية",
    "urdu": "أردية",
    "uyghur": "أويغورية",
    "uzbek": "أوزبكية",
    "venda": "فيندية",
    "vietnamese": "فيتنامية",
    "volapük": "فولابوكية",
    "walloon": "والونية",
    "waray": "واراي واراي",
    "welsh": "ويلزية",
    "wolof": "ولوفية",
    "xhosa": "خوسية",
    "yiddish": "يديشية",
    # "yoruba":"يوربا",
    "zulu": "زولوية",
    "молдовеняскэ": "مولدوفية",
}

LANGUAGE_SUFFIX_FORMATS = {
    # " language" : "لغة {}",
    "-language": "اللغة ال{}",
    " languages": "اللغات ال{}",
}

for language_key, arabic_name in PRIMARY_LANGUAGE_TRANSLATIONS.items():
    normalized_key = language_key.lower()
    language_key_translations[f"{normalized_key} language"] = f"لغة {arabic_name}"
    for suffix_pattern, suffix_label in LANGUAGE_SUFFIX_FORMATS.items():
        translation_key = f"{normalized_key}{suffix_pattern.lower()}"
        language_key_translations[translation_key] = suffix_label.format(arabic_name)

COMPLEX_LANGUAGE_TRANSLATIONS = {
    "west frisian": "فريزية غربية",
    "sorani": "كردية سورانية",
    "simple english": "إنجليزية بسيطة",
    "serbo-croatian": "صربية كرواتية",
    "northern sami": "سامي شمالية",
    "dutch low saxon": "هولندية سكسونية سفلى",
    "western frisian": "فريزية غربية",
    "south ndebele": "نديبلي جنوبية",
    "seselwa creole french": "كريولية سيشيلية",
    "scottish gaelic": "غيلية إسكتلندية",
    "north ndebele": "نديبيل شمالية",
    "norwegian bokmål": "نرويجية بوكمول",
    "norwegian nynorsk": "نرويجية نينوشك",
    "haitian creole": "كريولية هايتية",
    "church slavic": "سلافونية كنسية قديمة",
}

for language_key, arabic_name in COMPLEX_LANGUAGE_TRANSLATIONS.items():
    normalized_key = language_key.lower()
    language_key_translations[f"{normalized_key} language"] = f"لغة {arabic_name}"
    arabic_name = arabic_name.replace(" ", " ال")
    # lab = re.sub(r" " , " ال" , lab )
    # language_key_translations[x2] = "ال%s" % lab
    language_key_translations[normalized_key] = arabic_name
    for suffix_pattern in LANGUAGE_SUFFIX_FORMATS:
        translation_key = f"{normalized_key}{suffix_pattern}"
        language_key_translations[translation_key] = LANGUAGE_SUFFIX_FORMATS[suffix_pattern].format(arabic_name)

LANGUAGE_TOPIC_FORMATS = {
    "grammar": "قواعد {}",
    "romanization": "رومنة {}",
    "writing system": "نظام كتابة {}",
    "dialects": "لهجات {}",
    "surnames": "ألقاب {}",
    "masculine given names": "أسماء ذكور ب{}",
    "given names": "أسماء شخصية {}",
    "varieties and styles": "أصناف وأساليب {}",
    "literature": "أدب {}",
    "culture": "ثقافة {}",
    "underground culture": "ثقافة باطنية {}",
    "mass media": "إعلام {}",
    "countries": "بلدان {}",
    "categories": "تصنيفات {}",
    "education": "تعليم {}",
}

MEDIA_CATEGORY_TRANSLATIONS = {
    "words and phrases": "كلمات وجمل",
    "academic journals": "دوريات أكاديمية",
    "albums": "ألبومات",
    "books": "كتب",
    "comic book": "كتب قصص مصورة",
    "comic strips": "شرائط كومكس",
    "comic": "قصص مصورة",
    "comics": "قصص مصورة",
    "marvel comics": "مارفال كومكس",
    "dictionaries": "قواميس",
    "encyclopedias": "موسوعات",
    "films": "أفلام",
    "given names": "أسماء شخصية",
    "graphic novels": "روايات مصورة",
    "inscriptions": "نقوش",
    "literary awards": "جوائز أدبية",
    # "literary critics" : "نقد أدبي",
    "magazines": "مجلات",
    "manga": "مانغا",
    "media": "إعلام",
    "medieval literature": "أدب العصور الوسطى",
    "music": "موسيقى",
    "musicians": "موسيقيون",
    "names": "أسماء",
    "newspapers": "صحف",
    "novels": "روايات",
    "novellas": "روايات قصيرة",
    "operas": "أوبيرات",
    "people": "أشخاص",
    "plays": "مسرحيات",
    "poems": "قصائد",
    "publications": "منشورات",
    "radio stations": "محطات إذاعية",
    "short stories": "قصص قصيرة",
    "songs": "أغان",
    "surnames": "ألقاب",
    "telenovelas": "تيلينوفيلا",
    "television seasons": "مواسم تلفزيونية",
    "television episodes": "حلقات تلفزيونية",
    "television series": "مسلسلات تلفزيونية",
    "film series": "سلاسل أفلام",
    "television shows": "عروض تلفزيونية",
    "television networks": "شبكات تلفزيونية",
    "television programs": "برامج تلفزيونية",
    "television programmes": "برامج تلفزيونية",
    "television stations": "محطات تلفزيونية",
    "television": "تلفاز",
    "verbs": "أفعال",
    "video games": "ألعاب فيديو",
    "webcomic": "ويب كومكس",
    "webcomics": "ويب كومكس",
    "websites": "مواقع ويب",
    "works": "أعمال",
    # "Bible translations
    # "Compositions مؤلفات موسيقية
    # "tirukkural translations" : "",
}

ALBUMS_TYPE: dict[str, str] = {
    "folktronica": "فولكترونيكا",
    "concept": "مفاهيمية",
    "surprise": "مفاجئة",
    "comedy": "كوميدية",
    "mixtape": "ميكستايب",
    "remix": "ريمكس",
    "animation": "رسوم متحركة",
    "video": "فيديو",
    "compilation": "تجميعية",
    "live": "مباشرة",
    "jazz": "جاز",
    "eps": "أسطوانة مطولة",
    "folk": "فولك",
}
for album_type in ALBUMS_TYPE:
    MEDIA_CATEGORY_TRANSLATIONS[f"{album_type} albums"] = f"ألبومات {ALBUMS_TYPE[album_type]}"
# ---
for media_key, media_label in MEDIA_CATEGORY_TRANSLATIONS.items():
    LANGUAGE_TOPIC_FORMATS[media_key.lower()] = f"{media_label} ب{{}}"

len_print.data_len(
    "languages.py",
    {
        "language_key_translations": language_key_translations,
        "PRIMARY_LANGUAGE_TRANSLATIONS": PRIMARY_LANGUAGE_TRANSLATIONS,
        "COMPLEX_LANGUAGE_TRANSLATIONS": COMPLEX_LANGUAGE_TRANSLATIONS,
        "LANGUAGE_SUFFIX_FORMATS": LANGUAGE_SUFFIX_FORMATS,
        "LANGUAGE_TOPIC_FORMATS": LANGUAGE_TOPIC_FORMATS,
    },
)
__all__ = [
    "language_key_translations",
    "PRIMARY_LANGUAGE_TRANSLATIONS",
    "COMPLEX_LANGUAGE_TRANSLATIONS",
    "LANGUAGE_TOPIC_FORMATS",
]



"""
Tests
"""

import pytest

from ArWikiCats import resolve_label_ar

list_data_0 = {
    "Bahrain AFC Asian Cup squad navigational boxes": "صناديق تصفح تشكيلات البحرين في كأس آسيا",
}

list_data = {
    # "1880 european competition for women's football squad templates": "قوالب تشكيلات منافسات أوروبية في كرة القدم للسيدات 1880",
    "1904 Summer Olympics football squad navigational boxes": "صناديق تصفح تشكيلات كرة القدم في الألعاب الأولمبية الصيفية 1904",
    "1984 AFC Asian Cup squad navigational boxes": "صناديق تصفح تشكيلات كأس آسيا 1984",
    "1952 Summer Olympics field hockey squad navigational boxes": "صناديق تصفح تشكيلات هوكي الميدان في الألعاب الأولمبية الصيفية 1952",
    "2022 European Women's Handball Championship squad templates": "قوالب تشكيلات بطولة أوروبا لكرة اليد للسيدات 2022",
    "1880 fifa women's world cup squad navigational boxes": "صناديق تصفح تشكيلات كأس العالم لكرة القدم للسيدات 1880",
    "1880 afc asian cup squad navigational boxes": "صناديق تصفح تشكيلات كأس آسيا 1880",
    "1880 afc women's asian cup squad navigational boxes": "صناديق تصفح تشكيلات كأس الأمم الآسيوية لكرة القدم للسيدات 1880",
    "1880 afc women's championship squad navigational boxes": "صناديق تصفح تشكيلات بطولة آسيا للسيدات 1880",
    "1880 africa cup-of-nations squad navigational boxes": "صناديق تصفح تشكيلات كأس الأمم الإفريقية 1880",
    "1880 african cup of nations squad navigational boxes": "صناديق تصفح تشكيلات كأس الأمم الإفريقية 1880",
    "1880 african women's championship squad navigational boxes": "صناديق تصفح تشكيلات كأس أمم إفريقيا لكرة القدم للسيدات 1880",
    "1880 basketball olympic squad templates": "قوالب تشكيلات كرة سلة أولمبية 1880",
    "1880 concacaf championships squad navigational boxes": "صناديق تصفح تشكيلات بطولات الكونكاكاف 1880",
    "1880 concacaf gold cup squad templates": "قوالب تشكيلات كأس الكونكاكاف الذهبية 1880",
    "1880 concacaf women's championship squad navigational boxes": "صناديق تصفح تشكيلات بطولة أمريكا الشمالية للسيدات 1880",
    "1880 copa américa femenina squad navigational boxes": "صناديق تصفح تشكيلات كوبا أمريكا فمنينا 1880",
    "1880 copa américa squad navigational boxes": "صناديق تصفح تشكيلات كوبا أمريكا 1880",
    "1880 cricket world cup squad navigational boxes": "صناديق تصفح تشكيلات كأس العالم للكريكت 1880",
    "1880 european men's handball championship squad templates": "قوالب تشكيلات بطولة أوروبا لكرة اليد للرجال 1880",
    "1880 european women's handball championship squad templates": "قوالب تشكيلات بطولة أوروبا لكرة اليد للسيدات 1880",
    "1880 fiba asia championship squad templates": "قوالب تشكيلات بطولة أمم آسيا لكرة السلة 1880",
    "1880 fiba asia cup squad templates": "قوالب تشكيلات كأس أمم آسيا لكرة السلة 1880",
    "1880 fiba basketball world cup squad templates": "قوالب تشكيلات كأس العالم لكرة السلة 1880",
    "1880 fiba women's basketball world cup squad templates": "قوالب تشكيلات كأس العالم لكرة السلة للسيدات 1880",
    "1880 fiba world championship for women squad templates": "قوالب تشكيلات بطولة كأس العالم لكرة السلة للسيدات 1880",
    "1880 fiba world championship squad templates": "قوالب تشكيلات بطولة كأس العالم لكرة السلة 1880",
    "1880 fiba world cup squad templates": "قوالب تشكيلات كأس العالم لكرة السلة 1880",
    "1880 fifa confederations cup squad navigational boxes": "صناديق تصفح تشكيلات كأس القارات 1880",
    "1880 men's hockey world cup squad navigational boxes": "صناديق تصفح تشكيلات كأس العالم للهوكي للرجال 1880",
    "1880 oceania cup squad navigational boxes": "صناديق تصفح تشكيلات كأس أوقيانوسيا 1880",
    "1880 ofc nations cup squad navigational boxes": "صناديق تصفح تشكيلات كأس أوقيانوسيا للأمم 1880",
    "1880 pan american games squad navigational boxes": "صناديق تصفح تشكيلات دورة الألعاب الأمريكية 1880",
    "1880 rugby league world cup squad navigational boxes": "صناديق تصفح تشكيلات كأس العالم لدوري الرجبي 1880",
    "1880 rugby world cup squad navigational boxes": "صناديق تصفح تشكيلات كأس العالم للرجبي 1880",
    "1880 rugby world cup squad templates": "قوالب تشكيلات كأس العالم للرجبي 1880",
    "1880 south american championship (argentina) squad navigational boxes": "صناديق تصفح تشكيلات كأس أمريكا الجنوبية (الأرجنتين) 1880",
    "1880 south american championship (ecuador) squad navigational boxes": "صناديق تصفح تشكيلات كأس أمريكا الجنوبية (الإكوادور) 1880",
    "1880 south american championship squad navigational boxes": "صناديق تصفح تشكيلات بطولة أمريكا الجنوبية 1880",
    "1880 summer olympics basketball squad navigational boxes": "صناديق تصفح تشكيلات كرة السلة في الألعاب الأولمبية الصيفية 1880",
    "1880 summer olympics field hockey squad navigational boxes": "صناديق تصفح تشكيلات هوكي الميدان في الألعاب الأولمبية الصيفية 1880",
    "1880 summer olympics football squad navigational boxes": "صناديق تصفح تشكيلات كرة القدم في الألعاب الأولمبية الصيفية 1880",
    "1880 summer olympics handball squad navigational boxes": "صناديق تصفح تشكيلات كرة اليد في الألعاب الأولمبية الصيفية 1880",
    "1880 summer olympics rugby sevens squad navigational boxes": "صناديق تصفح تشكيلات سباعيات الرجبي في الألعاب الأولمبية الصيفية 1880",
    "1880 summer olympics squad navigational boxes": "صناديق تصفح تشكيلات الألعاب الأولمبية الصيفية 1880",
    "1880 summer olympics volleyball squad navigational boxes": "صناديق تصفح تشكيلات كرة الطائرة في الألعاب الأولمبية الصيفية 1880",
    "1880 summer olympics water polo squad navigational boxes": "صناديق تصفح تشكيلات كرة الماء في الألعاب الأولمبية الصيفية 1880",
    "1880 women's cricket world cup squad navigational boxes": "صناديق تصفح تشكيلات كأس العالم للكريكت للسيدات 1880",
    "1880 women's field hockey world cup squad navigational boxes": "صناديق تصفح تشكيلات كأس العالم لهوكي الميدان للسيدات 1880",
    "1880 women's hockey world cup squad navigational boxes": "صناديق تصفح تشكيلات كأس العالم للهوكي للسيدات 1880",
    "1880 women's rugby world cup squad navigational boxes": "صناديق تصفح تشكيلات كأس العالم للرجبي للسيدات 1880",
    "1880 women's rugby world cup squad templates": "قوالب تشكيلات كأس العالم للرجبي للسيدات 1880",
    "1880 world men's handball championship squad templates": "قوالب تشكيلات بطولة العالم لكرة اليد للرجال 1880",
    "1880 world women's handball championship squad templates": "قوالب تشكيلات بطولة العالم لكرة اليد للسيدات 1880",
    "2004 summer olympics football squad navigational boxes": "صناديق تصفح تشكيلات كرة القدم في الألعاب الأولمبية الصيفية 2004",
}


@pytest.mark.parametrize("category, expected_key", list_data.items(), ids=list_data.keys())
@pytest.mark.fast
def test_list_data(category: str, expected_key: str) -> None:
    label = resolve_label_ar(category)
    assert label == expected_key


@pytest.mark.parametrize("category, expected_key", list_data.items(), ids=list_data.keys())
@pytest.mark.fast
def test_squad_with_resolve(category: str, expected_key: str) -> None:
    label = resolve_label_ar(category)
    assert label == expected_key


@pytest.mark.fast
def test_resolve_squads_labels_and_templates() -> None:
    # Test with a basic input
    result = resolve_label_ar("test category")
    assert isinstance(result, str)

    # Test with squad templates
    result_squad = resolve_label_ar("2020 squad templates")
    assert isinstance(result_squad, str)
    assert result_squad == "قوالب تشكيلات 2020"

    # Test with empty strings
    result_empty = resolve_label_ar("")
    assert isinstance(result_empty, str)
    assert result_empty == ""



"""
Tests
"""

import pytest

from ArWikiCats.legacy_bots.ma_bots.ye_ts_bot import (
    find_lab,
    translate_general_category,
    work_separator_names,
)

fast_data = {}


@pytest.mark.parametrize("category, expected", fast_data.items(), ids=fast_data.keys())
@pytest.mark.fast
def test_fast_data(category: str, expected: str) -> None:
    label = translate_general_category(category)
    assert label == expected


def test_find_lab() -> None:
    # Test with a basic input
    result = find_lab("test category", "test_category")
    assert isinstance(result, str)

    result_empty = find_lab("", "")
    assert isinstance(result_empty, str)

    # Test with various inputs
    result_various = find_lab("sports category", "sports_category")
    assert isinstance(result_various, str)


def test_work_separator_names() -> None:
    # Test with a basic input
    result = work_separator_names("test category", "test category", True)
    assert isinstance(result, str)

    result_empty = work_separator_names("", "", False)
    assert isinstance(result_empty, str)

    # Test with various inputs
    result_various = work_separator_names("sports", "sports category", True)
    assert isinstance(result_various, str)


def test_translate_general_category() -> None:
    # Test with a basic input
    result = translate_general_category("test category")
    assert isinstance(result, str)

    result_empty = translate_general_category("")
    assert isinstance(result_empty, str)

    # Test with various inputs
    result_various = translate_general_category("sports category", False)
    assert isinstance(result_various, str)



#
import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats import resolve_arabic_category_label

national_championships_data = {
    "dutch national track cycling championships": "تصنيف:بطولات سباق الدراجات على المضمار وطنية هولندية",
    "asian national weightlifting championships": "تصنيف:بطولات رفع أثقال وطنية آسيوية",
}

championships_data = {
    "asian weightlifting championships": "تصنيف:بطولة آسيا لرفع الأثقال",
    "asian wushu championships": "تصنيف:بطولة آسيا للووشو",
    "australian netball championships": "تصنيف:بطولة أستراليا لكرة الشبكة",
    "bulgarian athletics championships": "تصنيف:بطولة بلغاريا لألعاب القوى",
    "czech figure skating championships": "تصنيف:بطولة التشيك للتزلج الفني",
    "czechoslovak athletics championships": "تصنيف:بطولة تشيكوسلوفاكيا لألعاب القوى",
    "european cross country championships": "تصنيف:بطولة أوروبا للعدو الريفي",
    "european diving championships": "تصنيف:بطولة أوروبا للغطس",
    "european table tennis championships": "تصنيف:بطولة أوروبا لكرة الطاولة",
    "european taekwondo championships": "تصنيف:بطولة أوروبا للتايكوندو",
    "european wrestling championships": "تصنيف:بطولة أوروبا للمصارعة",
    "french athletics championships": "تصنيف:بطولة فرنسا لألعاب القوى",
    "lithuanian athletics championships": "تصنيف:بطولة ليتوانيا لألعاب القوى",
    "lithuanian swimming championships": "تصنيف:بطولة ليتوانيا للسباحة",
    "paraguayan athletics championships": "تصنيف:بطولة باراغواي لألعاب القوى",
    "slovak figure skating championships": "تصنيف:بطولة سلوفاكيا للتزلج الفني",
    "south american gymnastics championships": "تصنيف:بطولة أمريكا الجنوبية للجمباز",
    "turkish figure skating championships": "تصنيف:بطولة تركيا للتزلج الفني",
    "african judo championships": "تصنيف:بطولة إفريقيا للجودو",
    "african swimming championships": "تصنيف:بطولة إفريقيا للسباحة",
    "asian athletics championships": "تصنيف:بطولة آسيا لألعاب القوى",
    "asian swimming championships": "تصنيف:بطولة آسيا للسباحة",
    "asian wrestling championships": "تصنيف:بطولة آسيا للمصارعة",
    "canadian wheelchair curling championships": "تصنيف:بطولة كندا للكيرلنغ على الكراسي المتحركة",
    "european amateur boxing championships": "تصنيف:بطولة أوروبا للبوكسينغ للهواة",
    "european beach volleyball championships": "تصنيف:بطولة أوروبا لكرة الطائرة الشاطئية",
    "european fencing championships": "تصنيف:بطولة أوروبا لمبارزة سيف الشيش",
    "european judo championships": "تصنيف:بطولة أوروبا للجودو",
    "european karate championships": "تصنيف:بطولة أوروبا للكاراتيه",
    "european speed skating championships": "تصنيف:بطولة أوروبا لتزلج السريع",
    "south american swimming championships": "تصنيف:بطولة أمريكا الجنوبية للسباحة",
    "world karate championships": "تصنيف:بطولة العالم للكاراتيه",
}


@pytest.mark.parametrize(
    "category, expected", national_championships_data.items(), ids=national_championships_data.keys()
)
def test_national_championships_data(category: str, expected: str) -> None:
    assert resolve_arabic_category_label(category) == expected


@pytest.mark.parametrize("category, expected", championships_data.items(), ids=championships_data.keys())
def test_championships_data(category: str, expected: str) -> None:
    assert resolve_arabic_category_label(category) == expected


to_test = [
    ("test_national_championships_data", national_championships_data),
    ("test_championships_data", championships_data),
]


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.dump
def test_dump_it(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_arabic_category_label)
    dump_diff(diff_result, name)

    add_result = {x: v for x, v in data.items() if x in diff_result and "" == diff_result.get(x)}
    dump_diff(add_result, f"{name}_add")
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"
